oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Adjunction.Limes

Description

mapping of Limits under Adjunctions.

Synopsis

Multiplicative

lmPrjMap :: forall (h :: Type -> Type -> Type) d c (t :: DiagramType) (n :: N') (m :: N'). HomMultiplicative h => Adjunction h d c -> Limes Mlt 'Projective t n m d -> Limes Mlt 'Projective t n m c Source #

mapping a projective limes under an adjunction.

lmInjMap :: forall (h :: Type -> Type -> Type) d c (t :: DiagramType) (n :: N') (m :: N'). HomMultiplicative h => Adjunction h d c -> Limes Mlt 'Injective t n m c -> Limes Mlt 'Injective t n m d Source #

mapping a injective limes under an adjunction.

Distributive

lmPrjMapDst :: forall (h :: Type -> Type -> Type) d c (t :: DiagramType) (n :: N') (m :: N'). HomDistributive h => Adjunction h d c -> Limes Dst 'Projective t n m d -> Limes Dst 'Projective t n m c Source #

mapping a projective limes under an adjunction.

lmInjMapDst :: forall (h :: Type -> Type -> Type) d c (t :: DiagramType) (n :: N') (m :: N'). HomDistributive h => Adjunction h d c -> Limes Dst 'Injective t n m c -> Limes Dst 'Injective t n m d Source #

mapping an injective limes according to a given Adjunction.