oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Data.Identity

Description

identical predicate.

Synopsis

Id

newtype Id x Source #

identical predicate.

Constructors

Id x 

Instances

Instances details
Foldable Id Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

fold :: Monoid m => Id m -> m #

foldMap :: Monoid m => (a -> m) -> Id a -> m #

foldMap' :: Monoid m => (a -> m) -> Id a -> m #

foldr :: (a -> b -> b) -> b -> Id a -> b #

foldr' :: (a -> b -> b) -> b -> Id a -> b #

foldl :: (b -> a -> b) -> b -> Id a -> b #

foldl' :: (b -> a -> b) -> b -> Id a -> b #

foldr1 :: (a -> a -> a) -> Id a -> a #

foldl1 :: (a -> a -> a) -> Id a -> a #

toList :: Id a -> [a] #

null :: Id a -> Bool #

length :: Id a -> Int #

elem :: Eq a => a -> Id a -> Bool #

maximum :: Ord a => Id a -> a #

minimum :: Ord a => Id a -> a #

sum :: Num a => Id a -> a #

product :: Num a => Id a -> a #

TransformableGObjectClassRange Id OrtX EqualExtOrt Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

TransformableG Id OrtX EqE Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tauG :: Struct OrtX x -> Struct EqE (Id x) Source #

TransformableG Id OrtX EqEOrt Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tauG :: Struct OrtX x -> Struct EqEOrt (Id x) Source #

DualisableG OrtX EqualExtOrt Op Id Source # 
Instance details

Defined in OAlg.Category.Dualisable

Methods

toDualG :: Struct OrtX x -> EqualExtOrt (Id x) (Id (Op x)) Source #

fromDualG :: Struct OrtX x -> EqualExtOrt (Id (Op x)) (Id x) Source #

ReflexiveG OrtX EqualExtOrt Op Id Source # 
Instance details

Defined in OAlg.Category.Dualisable

Methods

reflG :: Struct OrtX x -> Inv2 EqualExtOrt (Id x) (Id (Op (Op x))) Source #

(TransformableDst s, TransformableGRefl o s, DualisableDistributive s o, TransformableGRefl Matrix s) => ApplicativeMorCo Id Matrix s o (->) Source # 
Instance details

Defined in OAlg.Entity.Matrix.Definition

(TransformableDst s, TransformableGRefl o s, DualisableDistributive s o, TransformableGRefl Matrix s) => FunctorialHomCo Id Matrix s o (->) Source # 
Instance details

Defined in OAlg.Entity.Matrix.Definition

ApplicativeG Id GLApp (->) Source # 
Instance details

Defined in OAlg.Entity.Matrix.GeneralLinearGroup

Methods

amapG :: GLApp x y -> Id x -> Id y Source #

ApplicativeG Id TrApp (->) Source # 
Instance details

Defined in OAlg.Entity.Matrix.GeneralLinearGroup

Methods

amapG :: TrApp x y -> Id x -> Id y Source #

XStandardOrtSite 'From x => XStandardOrtSite 'From (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

XStandardOrtSite 'To x => XStandardOrtSite 'To (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

ApplicativeG Id h c => ApplicativeG Id (Inv2 h) c Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

amapG :: Inv2 h x y -> c (Id x) (Id y) Source #

ApplicativeG Id h c => ApplicativeG Id (Id2 h) c Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

amapG :: Id2 h x y -> c (Id x) (Id y) Source #

ApplicativeG Id (HomEmpty s) c Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomEmpty s x y -> c (Id x) (Id y) Source #

FunctorialG Id h c => FunctorialG Id (Inv2 h) c Source # 
Instance details

Defined in OAlg.Data.Identity

TransformableOrt s => ApplicativeG Id (Ornt s) (->) Source # 
Instance details

Defined in OAlg.Data.Ornt

Methods

amapG :: Ornt s x y -> Id x -> Id y Source #

(Semiring r, Commutative r) => ApplicativeG Id (HomSymbol r) (->) Source # 
Instance details

Defined in OAlg.Entity.Matrix.Vector

Methods

amapG :: HomSymbol r x y -> Id x -> Id y Source #

ApplicativeG Id (SliceFactorDrop s) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Definition

Methods

amapG :: SliceFactorDrop s x y -> Id x -> Id y Source #

ApplicativeG Id (HomId s) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomId s x y -> Id x -> Id y Source #

(Transformable r Type, TransformableOp r) => DualisableG r (->) Op Id Source # 
Instance details

Defined in OAlg.Category.Dualisable

Methods

toDualG :: Struct r x -> Id x -> Id (Op x) Source #

fromDualG :: Struct r x -> Id (Op x) -> Id x Source #

Transformable r Type => ReflexiveG r (->) Op Id Source # 
Instance details

Defined in OAlg.Category.Dualisable

Methods

reflG :: Struct r x -> Inv2 (->) (Id x) (Id (Op (Op x))) Source #

ApplicativeG Id (->) (->) Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

amapG :: (x -> y) -> Id x -> Id y Source #

(Morphism h, ApplicativeG Id h c, DualisableG s c o Id, c ~ (->)) => ApplicativeG Id (HomDisj s o h) c Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomDisj s o h x y -> c (Id x) (Id y) Source #

(Morphism h, ApplicativeG Id h c, DualisableG s c o Id, c ~ (->)) => FunctorialG Id (HomDisj s o h) c Source # 
Instance details

Defined in OAlg.Hom.Definition

TransformableGObjectClassDomain Id (HomDisj OrtX Op (HomEmpty OrtX)) EqEOrt Source # 
Instance details

Defined in OAlg.Hom.Definition

(TransformableDst s, TransformableGRefl o s, DualisableDistributive s o, TransformableGRefl Matrix s) => ApplicativeG Id (MorCo Matrix s o) (->) Source # 
Instance details

Defined in OAlg.Entity.Matrix.Definition

Methods

amapG :: MorCo Matrix s o x y -> Id x -> Id y Source #

(Distributive d, Sliced i d, Conic c) => ApplicativeG Id (SliceAdjunction i c d) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Adjunction

Methods

amapG :: SliceAdjunction i c d x y -> Id x -> Id y Source #

ApplicativeG Id h c => ApplicativeG Id (Variant2 v h) c Source # 
Instance details

Defined in OAlg.Data.Variant

Methods

amapG :: Variant2 v h x y -> c (Id x) (Id y) Source #

Bounded x => Bounded (Id x) Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

minBound :: Id x #

maxBound :: Id x #

Enum x => Enum (Id x) Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

succ :: Id x -> Id x #

pred :: Id x -> Id x #

toEnum :: Int -> Id x #

fromEnum :: Id x -> Int #

enumFrom :: Id x -> [Id x] #

enumFromThen :: Id x -> Id x -> [Id x] #

enumFromTo :: Id x -> Id x -> [Id x] #

enumFromThenTo :: Id x -> Id x -> Id x -> [Id x] #

Read x => Read (Id x) Source # 
Instance details

Defined in OAlg.Data.Identity

Show x => Show (Id x) Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

showsPrec :: Int -> Id x -> ShowS #

show :: Id x -> String #

showList :: [Id x] -> ShowS #

Eq x => Eq (Id x) Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

(==) :: Id x -> Id x -> Bool #

(/=) :: Id x -> Id x -> Bool #

Ord x => Ord (Id x) Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

compare :: Id x -> Id x -> Ordering #

(<) :: Id x -> Id x -> Bool #

(<=) :: Id x -> Id x -> Bool #

(>) :: Id x -> Id x -> Bool #

(>=) :: Id x -> Id x -> Bool #

max :: Id x -> Id x -> Id x #

min :: Id x -> Id x -> Id x #

Validable x => Validable (Id x) Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

valid :: Id x -> Statement Source #

XStandard x => XStandard (Id x) Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

xStandard :: X (Id x) Source #

Additive a => Additive (Id a) Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

zero :: Root (Id a) -> Id a Source #

(+) :: Id a -> Id a -> Id a Source #

ntimes :: N -> Id a -> Id a Source #

XStandardAdd x => XStandardAdd (Id x) Source # 
Instance details

Defined in OAlg.Structure.Additive.Proposition

Methods

xStandardAdd :: XAdd (Id x) Source #

Distributive d => Distributive (Id d) Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

XStandardDst x => XStandardDst (Id x) Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

xStandardDst :: XDst (Id x) Source #

Fibred x => Fibred (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Definition

Methods

root :: Id x -> Root (Id x) Source #

EqRoot x => EqRoot (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

ShowRoot x => ShowRoot (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

SingletonRoot x => SingletonRoot (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

TypeableRoot x => TypeableRoot (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

ValidableRoot x => ValidableRoot (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

FibredOriented x => FibredOriented (Id x) Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Multiplicative c => Multiplicative (Id c) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

one :: Point (Id c) -> Id c Source #

(*) :: Id c -> Id c -> Id c Source #

npower :: Id c -> N -> Id c Source #

XStandardMlt c => XStandardMlt (Id c) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

xStandardMlt :: XMlt (Id c) Source #

Oriented x => Oriented (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

orientation :: Id x -> Orientation (Point (Id x)) Source #

start :: Id x -> Point (Id x) Source #

end :: Id x -> Point (Id x) Source #

EqPoint x => EqPoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

OrdPoint x => OrdPoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

ShowPoint x => ShowPoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

SingletonPoint x => SingletonPoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

TypeablePoint x => TypeablePoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

ValidablePoint x => ValidablePoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

XStandardPoint x => XStandardPoint (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

XStandardOrtOrientation x => XStandardOrtOrientation (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

XStandardOrtSiteFrom x => XStandardOrtSiteFrom (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

XStandardOrtSiteTo x => XStandardOrtSiteTo (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

type Root (Id x) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

type Root (Id x) = Root x
type Point (Id x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

type Point (Id x) = Point x

fromId :: Id x -> x Source #

deconstructs Id.

trafoFromId :: (y -> i z) -> (x -> Id y) -> x -> i z Source #

transforming a f :: x -> Id y to a f' :: x -> i z.

trafoToId :: (x -> y) -> x -> Id y Source #

transforming a f :: x -> y to a f' :: x -> Id y.

toIdG :: (x -> y) -> Id x -> Id y Source #

the induced mapping.

fromIdG :: (Id x -> Id y) -> x -> y Source #

the induced mapping.

Applicative

type Applicative (h :: Type -> Type -> Type) = ApplicativeG Id h (->) Source #

representable hs according to Id.

amap :: Applicative h => h x y -> x -> y Source #

representation of h in (->).

($) :: Applicative h => h x y -> x -> y infixr 0 Source #

right associative application on values.

type Functorial (c :: Type -> Type -> Type) = FunctorialG Id c (->) Source #

functorials form c to (->) according to Id.

amapf :: Functorial h => h x y -> x -> y Source #

functorial representation of h in (->).

data Functor (c :: Type -> Type -> Type) Source #

attest of being Functorial from the Category c to the Category (->).

Id2

newtype Id2 (h :: Type -> Type -> Type) x y Source #

identical predicat.

Constructors

Id2 (h x y) 

Instances

Instances details
ApplicativeG Id h c => ApplicativeG Id (Id2 h) c Source # 
Instance details

Defined in OAlg.Data.Identity

Methods

amapG :: Id2 h x y -> c (Id x) (Id y) Source #

ApplicativeG Pnt h c => ApplicativeG Pnt (Id2 h) c Source # 
Instance details

Defined in OAlg.Structure.Oriented.Point

Methods

amapG :: Id2 h x y -> c (Pnt x) (Pnt y) Source #

Morphism h => Morphism (Id2 h) Source # 
Instance details

Defined in OAlg.Data.Identity

Associated Types

type ObjectClass (Id2 h) 
Instance details

Defined in OAlg.Data.Identity

Methods

homomorphous :: Id2 h x y -> Homomorphous (ObjectClass (Id2 h)) x y Source #

domain :: Id2 h x y -> Struct (ObjectClass (Id2 h)) x Source #

range :: Id2 h x y -> Struct (ObjectClass (Id2 h)) y Source #

HomOriented h => HomOriented (Id2 h) Source # 
Instance details

Defined in OAlg.Hom.Oriented.Definition

type ObjectClass (Id2 h) Source # 
Instance details

Defined in OAlg.Data.Identity