| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Entity.Matrix.Dim
Description
dimension for matrices of x as a complete sequence of . Point x
Synopsis
- data Dim x p where
- type Dim' x = Dim x (Point x)
- fromDim :: Dim x p -> ProductSymbol p
- dim :: (Entity p, p ~ Point x) => p -> Dim x p
- productDim :: (Entity p, p ~ Point x) => [p] -> Dim x p
- dimxs :: p ~ Point x => Dim x p -> [(p, N)]
- dimwrd :: (Entity p, p ~ Point x) => Dim x p -> Word N p
- dimMap :: (Entity q, q ~ Point y) => (p -> q) -> Dim x p -> Dim y q
Documentation
dimension of x as a complete sequence of . Point x
Instances
fromDim :: Dim x p -> ProductSymbol p Source #
the underlying product.