oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Entity.Matrix.Proposition

Contents

Description

propositions on matrices.

Synopsis

Proposition

prpMatrix :: Distributive x => XOrtOrientation (Matrix x) -> XOrtSite 'From (Matrix x) -> XOrtSite 'To (Matrix x) -> Statement Source #

validity of the algebraic structure of matrices.

prpMatrixZ :: Statement Source #

validity of the algebraic structure of block matrices of Z.