oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Hom.Algebraic

Contents

Description

homomorphisms between Algebraic structures having the same associated Scalar.

Synopsis

Algebraic

class (HomDistributive h, HomVectorial k h, Transformable (ObjectClass h) (Alg k)) => HomAlgebraic k (h :: Type -> Type -> Type) Source #

type family of homomorphisms between Algebraic structures having the same associated Scalar.

Instances

Instances details
HomAlgebraic k h => HomAlgebraic k (Path h) Source # 
Instance details

Defined in OAlg.Hom.Algebraic