oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Hom.Definition

Description

basic definitions of homomorphisms.

Synopsis

Disjunctive

newtype HomDisj s (o :: Type -> Type) (h :: Type -> Type -> Type) x y Source #

disjunctive family of homomorphsims.

Constructors

HomDisj (SHom s s o h x y) 

Instances

Instances details
Disjunctive2 (HomDisj s o h :: Type -> Type -> Type) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

variant2 :: HomDisj s o h x y -> Variant Source #

(TransformableOrt s, TransformableType s, TransformableOp s) => HomSlicedOriented i (Sub (s, Sld i) (HomDisjEmpty s Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

(TransformableOrt s, TransformableType s, TransformableOp s) => HomSlicedOriented i (Sub (s, Sld i) (IsoO s Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

(Transformable s Ort, TransformableOp (s, Sld i)) => HomSlicedOriented i (HomDisjEmpty (s, Sld i) Op) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

TransformableObjectClass OrtX (HomDisj OrtX Op (HomEmpty OrtX)) Source # 
Instance details

Defined in OAlg.Hom.Definition

(Morphism h, TransformableGRefl o s) => CategoryDualisable o (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

cToDual :: Struct (ObjectClass (HomDisj s o h)) x -> Variant2 'Contravariant (HomDisj s o h) x (o x) Source #

cFromDual :: Struct (ObjectClass (HomDisj s o h)) x -> Variant2 'Contravariant (HomDisj s o h) (o x) x Source #

(HomVectorial k h, DualisableVectorial k s o) => HomVectorial k (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Vectorial

(Morphism h, ApplicativeG Id h c, DualisableG s c o Id, c ~ (->)) => ApplicativeG Id (HomDisj s o h) c Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomDisj s o h x y -> c (Id x) (Id y) Source #

(Morphism h, ApplicativeG Id h c, DualisableG s c o Id, c ~ (->)) => FunctorialG Id (HomDisj s o h) c Source # 
Instance details

Defined in OAlg.Hom.Definition

TransformableGObjectClassDomain Id (HomDisj OrtX Op (HomEmpty OrtX)) EqEOrt Source # 
Instance details

Defined in OAlg.Hom.Definition

TransformableGObjectClassDomain Pnt (HomDisj OrtX Op (HomEmpty OrtX)) EqEOrt Source # 
Instance details

Defined in OAlg.Hom.Definition

(HomOriented h, DualisableOriented s o) => ApplicativeG SomeDiagram (HomDisj s o h) (->) Source # 
Instance details

Defined in OAlg.Entity.Diagram.Definition

Methods

amapG :: HomDisj s o h x y -> SomeDiagram x -> SomeDiagram y Source #

(Morphism h, ApplicativeRoot h, DualisableG s (->) o Rt) => ApplicativeG Rt (HomDisj s o h) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomDisj s o h x y -> Rt x -> Rt y Source #

(Morphism h, ApplicativePoint h, DualisableG s (->) o Pnt) => ApplicativeG Pnt (HomDisj s o h) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomDisj s o h x y -> Pnt x -> Pnt y Source #

(HomOriented h, DualisableOriented s o) => FunctorialG SomeDiagram (HomDisj s o h) (->) Source # 
Instance details

Defined in OAlg.Entity.Diagram.Definition

(Morphism h, ApplicativeRoot h, DualisableG s (->) o Rt) => FunctorialG Rt (HomDisj s o h) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

(Morphism h, ApplicativePoint h, DualisableG s (->) o Pnt) => FunctorialG Pnt (HomDisj s o h) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

HomOrientedSlicedFree (Inv2 (HomFree Dst)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

HomOrientedSlicedFree (Inv2 (HomFree Mlt)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

(TransformableOrt s, TransformableType s, TransformableOp s) => HomOrientedSlicedFree (HomFree s) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

(NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'LeftToRight) N2 N1, NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'RightToLeft) N2 N1, p ~ Dual (Dual p), t ~ Dual (Dual t)) => ApplicativeG (SDualBi (ConeLiftable s p d t n m)) (Inv2 (HomFree s)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

amapG :: Inv2 (HomFree s) x y -> SDualBi (ConeLiftable s p d t n m) x -> SDualBi (ConeLiftable s p d t n m) y Source #

p ~ Dual (Dual p) => ApplicativeG (SDualBi (LiftableFree p)) (Inv2 (HomFree Dst)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

amapG :: Inv2 (HomFree Dst) x y -> SDualBi (LiftableFree p) x -> SDualBi (LiftableFree p) y Source #

p ~ Dual (Dual p) => ApplicativeG (SDualBi (LiftableFree p)) (Inv2 (HomFree Mlt)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

amapG :: Inv2 (HomFree Mlt) x y -> SDualBi (LiftableFree p) x -> SDualBi (LiftableFree p) y Source #

(NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'LeftToRight) N2 N1, NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'RightToLeft) N2 N1, p ~ Dual (Dual p), t ~ Dual (Dual t)) => FunctorialG (SDualBi (ConeLiftable s p d t n m)) (Inv2 (HomFree s)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

p ~ Dual (Dual p) => FunctorialG (SDualBi (LiftableFree p)) (Inv2 (HomFree Dst)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

p ~ Dual (Dual p) => FunctorialG (SDualBi (LiftableFree p)) (Inv2 (HomFree Mlt)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Attestable k => HomSlicedOriented (Free k) (Sub (Dst, SldFr) (HomDisjEmpty Dst Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Transformable s Typ => EqExt (HomDisjEmpty s Op) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

(.=.) :: HomDisjEmpty s Op x y -> HomDisjEmpty s Op x y -> Statement Source #

FunctorialOriented (Sub (Dst, SldFr) (HomDisjEmpty Dst Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

FunctorialOriented (Sub (Mlt, SldFr) (HomDisjEmpty Mlt Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Transformable (s, Sld i) s => TransformableObjectClass (s, Sld i) (HomDisjEmpty s Op) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

TransformableObjectClass (Dst, SldFr) (HomDisj Dst Op (HomEmpty Dst)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

TransformableObjectClass (Mlt, SldFr) (HomDisj Mlt Op (HomEmpty Mlt)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Morphism h => Category (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

cOne :: Struct (ObjectClass (HomDisj s o h)) x -> HomDisj s o h x x Source #

(.) :: HomDisj s o h y z -> HomDisj s o h x y -> HomDisj s o h x z Source #

Morphism h => Morphism (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

Associated Types

type ObjectClass (HomDisj s o h) 
Instance details

Defined in OAlg.Hom.Definition

type ObjectClass (HomDisj s o h) = s

Methods

homomorphous :: HomDisj s o h x y -> Homomorphous (ObjectClass (HomDisj s o h)) x y Source #

domain :: HomDisj s o h x y -> Struct (ObjectClass (HomDisj s o h)) x Source #

range :: HomDisj s o h x y -> Struct (ObjectClass (HomDisj s o h)) y Source #

(Morphism h, Eq2 h, Transformable s Typ) => Eq2 (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

eq2 :: HomDisj s o h x y -> HomDisj s o h x y -> Bool Source #

Show2 h => Show2 (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

show2 :: HomDisj s o h a b -> String Source #

(Morphism h, Validable2 h) => Validable2 (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

valid2 :: HomDisj s o h x y -> Statement Source #

Morphism h => CategoryDisjunctive (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

(HomAdditive h, DualisableAdditive s o) => HomAdditive (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Additive

(HomDistributive h, DualisableDistributive s o) => HomDistributiveDisjunctive (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Distributive

(HomFibred h, DualisableFibred s o) => FunctorialFibred (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Fibred

(HomFibred h, DualisableFibred s o) => HomFibred (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Fibred

(HomFibredOriented h, DualisableFibredOriented s o) => HomFibredOrientedDisjunctive (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.FibredOriented

(HomMultiplicative h, DualisableMultiplicative s o) => HomMultiplicativeDisjunctive (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Multiplicative

(HomOriented h, DualisableOriented s o) => FunctorialOriented (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Oriented.Definition

(HomOriented h, DualisableOriented s o) => HomOrientedDisjunctive (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Oriented.Definition

Show2 h => Show (HomDisj s o h x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

showsPrec :: Int -> HomDisj s o h x y -> ShowS #

show :: HomDisj s o h x y -> String #

showList :: [HomDisj s o h x y] -> ShowS #

(Morphism h, Eq2 h, Transformable s Typ) => Eq (HomDisj s o h x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

(==) :: HomDisj s o h x y -> HomDisj s o h x y -> Bool #

(/=) :: HomDisj s o h x y -> HomDisj s o h x y -> Bool #

(Morphism h, Validable2 h) => Validable (HomDisj s o h x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

valid :: HomDisj s o h x y -> Statement Source #

Disjunctive (HomDisj s o h x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

variant :: HomDisj s o h x y -> Variant Source #

type ObjectClass (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Definition

type ObjectClass (HomDisj s o h) = s

homDisj :: forall h s x y (o :: Type -> Type). (Morphism h, Transformable (ObjectClass h) s) => h x y -> Variant2 'Covariant (HomDisj s o h) x y Source #

canonical embedding of a h into HomDisj as a covariant morphism.

type HomDisjEmpty s (o :: Type -> Type) = HomDisj s o (HomEmpty s) Source #

Contravariant Isomorphism

type IsoHomDisj s (o :: Type -> Type) (h :: Type -> Type -> Type) = Inv2 (HomDisj s o h) Source #

type for contravariant isomorphism of HomDisj s o h x (o x).

isoHomDisj :: forall (h :: Type -> Type -> Type) o s x. (Morphism h, TransformableGRefl o s) => Struct s x -> Variant2 'Contravariant (IsoHomDisj s o h) x (o x) Source #

contravariant isomorphism for HomDisj s o h x (o x).

isoHomDisj' :: forall (h :: Type -> Type -> Type) o s q x. (Morphism h, TransformableGRefl o s) => q h -> Struct s x -> Variant2 'Contravariant (IsoHomDisj s o h) x (o x) Source #

contravariant isomorphism for HomDisj s o h x (o x) given by the proxy type.

type IsoO r (o :: Type -> Type) = Inv2 (HomDisjEmpty r o) Source #

the type for o-isomorphisms in the category HomDisjEmpty r o.

toDualO :: TransformableGRefl o r => Struct r x -> Variant2 'Contravariant (IsoO r o) x (o x) Source #

the contravariant to-dual o isomorphism.

toDualO' :: TransformableGRefl o r => q o -> Struct r x -> Variant2 'Contravariant (IsoO r o) x (o x) Source #

the contravariant to-dual o isomorphism.

type ReflO r (o :: Type -> Type) x = Variant2 'Covariant (IsoO r o) x (o (o x)) Source #

the type for covariant reflections.

reflO :: TransformableGRefl o r => Struct r x -> Variant2 'Covariant (IsoO r o) x (o (o x)) Source #

the covariant reflection.

Empty

data HomEmpty s x y Source #

the empty family of homomorphisms.

Instances

Instances details
ApplicativeG Id (HomEmpty s) c Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomEmpty s x y -> c (Id x) (Id y) Source #

ApplicativeG Rt (HomEmpty s) c Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomEmpty s x y -> c (Rt x) (Rt y) Source #

ApplicativeG Pnt (HomEmpty s) c Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomEmpty s x y -> c (Pnt x) (Pnt y) Source #

(TransformableOrt s, TransformableType s, TransformableOp s) => HomSlicedOriented i (Sub (s, Sld i) (HomDisjEmpty s Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

(TransformableOrt s, TransformableType s, TransformableOp s) => HomSlicedOriented i (Sub (s, Sld i) (IsoO s Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

(Transformable s Ort, TransformableOp (s, Sld i)) => HomSlicedOriented i (HomDisjEmpty (s, Sld i) Op) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

TransformableObjectClass OrtX (HomDisj OrtX Op (HomEmpty OrtX)) Source # 
Instance details

Defined in OAlg.Hom.Definition

TransformableGObjectClassDomain Id (HomDisj OrtX Op (HomEmpty OrtX)) EqEOrt Source # 
Instance details

Defined in OAlg.Hom.Definition

TransformableGObjectClassDomain Pnt (HomDisj OrtX Op (HomEmpty OrtX)) EqEOrt Source # 
Instance details

Defined in OAlg.Hom.Definition

Morphism (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Associated Types

type ObjectClass (HomEmpty s) 
Instance details

Defined in OAlg.Hom.Definition

type ObjectClass (HomEmpty s) = s
Eq2 (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

eq2 :: HomEmpty s x y -> HomEmpty s x y -> Bool Source #

EqExt (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

(.=.) :: HomEmpty s x y -> HomEmpty s x y -> Statement Source #

Show2 (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

show2 :: HomEmpty s a b -> String Source #

Validable2 (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

valid2 :: HomEmpty s x y -> Statement Source #

HomOrientedSlicedFree (Inv2 (HomFree Dst)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

HomOrientedSlicedFree (Inv2 (HomFree Mlt)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

(TransformableOrt s, TransformableType s, TransformableOp s) => HomOrientedSlicedFree (HomFree s) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

(TransformableFbr s, TransformableAdd s) => HomAdditive (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Additive

(TransformableOrt s, TransformableFbr s, TransformableFbrOrt s, TransformableMlt s, TransformableAdd s, TransformableDst s) => HomDistributive (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Distributive

TransformableFbr s => HomFibred (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Fibred

(TransformableOrt s, TransformableFbr s, TransformableFbrOrt s) => HomFibredOriented (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.FibredOriented

TransformableMlt s => HomMultiplicative (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Multiplicative

TransformableOrt s => HomOriented (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Oriented.Definition

(NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'LeftToRight) N2 N1, NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'RightToLeft) N2 N1, p ~ Dual (Dual p), t ~ Dual (Dual t)) => ApplicativeG (SDualBi (ConeLiftable s p d t n m)) (Inv2 (HomFree s)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

amapG :: Inv2 (HomFree s) x y -> SDualBi (ConeLiftable s p d t n m) x -> SDualBi (ConeLiftable s p d t n m) y Source #

p ~ Dual (Dual p) => ApplicativeG (SDualBi (LiftableFree p)) (Inv2 (HomFree Dst)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

amapG :: Inv2 (HomFree Dst) x y -> SDualBi (LiftableFree p) x -> SDualBi (LiftableFree p) y Source #

p ~ Dual (Dual p) => ApplicativeG (SDualBi (LiftableFree p)) (Inv2 (HomFree Mlt)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

amapG :: Inv2 (HomFree Mlt) x y -> SDualBi (LiftableFree p) x -> SDualBi (LiftableFree p) y Source #

(NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'LeftToRight) N2 N1, NaturalDiagrammatic (Inv2 (HomFree s)) d ('Parallel 'RightToLeft) N2 N1, p ~ Dual (Dual p), t ~ Dual (Dual t)) => FunctorialG (SDualBi (ConeLiftable s p d t n m)) (Inv2 (HomFree s)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

p ~ Dual (Dual p) => FunctorialG (SDualBi (LiftableFree p)) (Inv2 (HomFree Dst)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

p ~ Dual (Dual p) => FunctorialG (SDualBi (LiftableFree p)) (Inv2 (HomFree Mlt)) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Attestable k => HomSlicedOriented (Free k) (Sub (Dst, SldFr) (HomDisjEmpty Dst Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Transformable s Typ => EqExt (HomDisjEmpty s Op) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

(.=.) :: HomDisjEmpty s Op x y -> HomDisjEmpty s Op x y -> Statement Source #

FunctorialOriented (Sub (Dst, SldFr) (HomDisjEmpty Dst Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

FunctorialOriented (Sub (Mlt, SldFr) (HomDisjEmpty Mlt Op)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Transformable (s, Sld i) s => TransformableObjectClass (s, Sld i) (HomDisjEmpty s Op) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

TransformableObjectClass (Dst, SldFr) (HomDisj Dst Op (HomEmpty Dst)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

TransformableObjectClass (Mlt, SldFr) (HomDisj Mlt Op (HomEmpty Mlt)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Show (HomEmpty s x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

showsPrec :: Int -> HomEmpty s x y -> ShowS #

show :: HomEmpty s x y -> String #

showList :: [HomEmpty s x y] -> ShowS #

Eq (HomEmpty s x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

(==) :: HomEmpty s x y -> HomEmpty s x y -> Bool #

(/=) :: HomEmpty s x y -> HomEmpty s x y -> Bool #

Validable (HomEmpty s x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

valid :: HomEmpty s x y -> Statement Source #

type ObjectClass (HomEmpty s) Source # 
Instance details

Defined in OAlg.Hom.Definition

type ObjectClass (HomEmpty s) = s

fromHomEmpty :: HomEmpty s a b -> x Source #

the empty map.

Id

data HomId s x y where Source #

isomorphisms for mappings between x and Id x and vice versa.

Constructors

ToId :: forall s x. (Structure s x, Structure s (Id x)) => HomId s x (Id x) 
FromId :: forall s y. (Structure s y, Structure s (Id y)) => HomId s (Id y) y 

Instances

Instances details
ApplicativeG Id (HomId s) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomId s x y -> Id x -> Id y Source #

ApplicativeG Pnt (HomId s) (->) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

amapG :: HomId s x y -> Pnt x -> Pnt y Source #

Morphism (HomId s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Associated Types

type ObjectClass (HomId s) 
Instance details

Defined in OAlg.Hom.Definition

type ObjectClass (HomId s) = s
Show2 (HomId s) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

show2 :: HomId s a b -> String Source #

TransformableOrt s => HomOriented (HomId s) Source # 
Instance details

Defined in OAlg.Hom.Oriented.Definition

Show (HomId s x y) Source # 
Instance details

Defined in OAlg.Hom.Definition

Methods

showsPrec :: Int -> HomId s x y -> ShowS #

show :: HomId s x y -> String #

showList :: [HomId s x y] -> ShowS #

type ObjectClass (HomId s) Source # 
Instance details

Defined in OAlg.Hom.Definition

type ObjectClass (HomId s) = s

Hom

type family Hom s (h :: Type -> Type -> Type) Source #

homomorphisms parameterized over s.

Instances

Instances details
type Hom Dst h Source # 
Instance details

Defined in OAlg.Hom.Distributive

type Hom Mlt h Source # 
Instance details

Defined in OAlg.Hom.Multiplicative

type family HomD s (h :: Type -> Type -> Type) Source #

disjunctive homomorphisms parameterized over s.

Instances

Instances details
type HomD Dst h Source # 
Instance details

Defined in OAlg.Hom.Distributive

type HomD Mlt h Source # 
Instance details

Defined in OAlg.Hom.Multiplicative

X

xscmHomDisj :: forall (o :: Type -> Type) s (h :: Type -> Type -> Type). (TransformableG o s s, Morphism h, Transformable (ObjectClass h) s) => X (SomeObjectClass (SHom s s o h)) -> X (SomeMorphism h) -> X (SomeCmpb2 (HomDisj s o h)) Source #

random variable for some composable HomDisj.