oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Hom.Distributive

Description

homomorphisms between Distributive structure.

Synopsis

Distributive

class (HomFibredOriented h, HomMultiplicative h, HomAdditive h, Transformable (ObjectClass h) Dst) => HomDistributive (h :: Type -> Type -> Type) Source #

covariant homomorphisms between Distributive structures.

homDisjOpDst :: HomDistributive h => h x y -> Variant2 'Covariant (HomDisj Dst Op h) x y Source #

canonical embedding of HomDistributive to HomDisj Dst Op.

Iso

toDualOpDst :: Distributive x => Variant2 'Contravariant (IsoO Dst Op) x (Op x) Source #

the canonical Contravariant isomorphism on Distributive structures between x and Op x.