oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Hom.FibredOriented

Description

definition of homomorphisms between FibredOriented structures.

Synopsis

Disjunctive

class (DualisableFibred s o, DualisableOriented s o, Transformable s FbrOrt) => DualisableFibredOriented s (o :: Type -> Type) Source #

duality according to o on FibredOriented-structures.

Property Let DualisableFibredOriented s o then for all x and s in Struct s x holds:

  1. toDualStk q s .=. toDualArw q s.
  2. toDualRt q s .=. toDualOrt q s.

Covariant

class (HomFibred h, HomOriented h, Transformable (ObjectClass h) FbrOrt) => HomFibredOriented (h :: Type -> Type -> Type) Source #

type family of homomorphisms between FibredOriented structures where rmap is given by omap.

Property Let HomFibredOriented h, then for all x, y and h in h x y holds:

  1. rmap h .=. omap h.

Iso

toDualOpFbrOrt :: FibredOriented x => Variant2 'Contravariant (IsoO FbrOrt Op) x (Op x) Source #

the canonical Contravariant isomorphism on FibredOriented structures between x and Op x.

Proposition

prpHomFbrOrt :: (HomFibredOriented h, Show2 h) => h x y -> Root x -> Statement Source #

validity accordint to HomFibredOriented.

prpDualisableFibredOrientedStk :: forall s (o :: Type -> Type) q x. DualisableFibredOriented s o => q o -> Struct s x -> x -> Statement Source #

validity according to DualisableFibredOriented.

prpDualisableFibredOrientedRt :: forall s (o :: Type -> Type) q x. DualisableFibredOriented s o => q o -> Struct s x -> Root x -> Statement Source #

validity according to DualisableFibredOriented.