oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Hom.Vectorial

Description

homomorphisms between Vectorial structures having the same associated Scalar.

Synopsis

Vectorial

class (HomAdditive h, Transformable (ObjectClass h) (Vec k)) => HomVectorial k (h :: Type -> Type -> Type) Source #

type family of homomorphisms between Vectorial structures having the same associated 'Scalar.

Property Let h be a type instance of the class HomVectorial k, then for all a, b, v in h a b and x in k holds: amap h (x ! v) == x ! amap h v.

Instances

Instances details
HomVectorial k h => HomVectorial k (Path h) Source # 
Instance details

Defined in OAlg.Hom.Vectorial

(Semiring r, Commutative r) => HomVectorial r (HomSymbol r) Source # 
Instance details

Defined in OAlg.Entity.Matrix.Vector

(HomVectorial k h, DualisableVectorial k s o) => HomVectorial k (HomDisj s o h) Source # 
Instance details

Defined in OAlg.Hom.Vectorial

class (DualisableAdditive s o, Transformable s (Vec k)) => DualisableVectorial k s (o :: Type -> Type) Source #

duality according to o on k-Vectorial structures.

Propoerty Let DualisableVectorial k s o then for all x, s in Struct s x and k in k holds:

  1. toDualStk q s (k ! x) == k ! toDualStk q s x.

where q is any proxy for o.

Proposition

prpHomVectorial :: HomVectorial k h => h x y -> k -> x -> Statement Source #

validity according to HomVectorial.

prpDualisableVectorial :: forall k s (o :: Type -> Type) q x. DualisableVectorial k s o => q o -> Struct s x -> k -> x -> Statement Source #

validity according to DualisableVectorial.

prpHomDisjOpVecZ :: Statement Source #

validity of HomDisjEmpty __(Vec Z) Op@ according to HomVectorial.