oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Cone.Conic.Core

Contents

Description

basic definition for objects with a naturally underlying cone.

Synopsis

Conic

class Conic (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) where Source #

object c having an underlying Cone.

Methods

cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. c s p d t n m x -> Cone s p d t n m x Source #

Instances

Instances details
Conic ConeLiftable Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. ConeLiftable s p d t n m x -> Cone s p d t n m x Source #

Conic Cone Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Core

Methods

cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. Cone s p d t n m x -> Cone s p d t n m x Source #

Conic ConeZeroHead Source # 
Instance details

Defined in OAlg.Limes.Cone.ZeroHead.Core

Methods

cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. ConeZeroHead s p d t n m x -> Cone s p d t n m x Source #

Conic c => Conic (ConicFreeTip c) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. ConicFreeTip c s p d t n m x -> Cone s p d t n m x Source #

Conic (LiftableCone i) Source # 
Instance details

Defined in OAlg.Entity.Slice.Liftable

Methods

cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. LiftableCone i s p d t n m x -> Cone s p d t n m x Source #

newtype ConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x Source #

wrapper for Conic-objects.

Constructors

ConeG (c s p d t n m x) 

Instances

Instances details
Conic c => Natural r (->) (SDualBi (ConeG c s p d t n m)) (SDualBi (ConeG Cone s p d t n m)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Core

Methods

roh :: Struct r x -> SDualBi (ConeG c s p d t n m) x -> SDualBi (ConeG Cone s p d t n m) x Source #

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalTransformable h (->) (SDualBi (ConeG Cone Dst p d t n m)) (SDualBi (ConeG Cone Dst p d t n m)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Duality

(HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalTransformable h (->) (SDualBi (ConeG Cone Mlt p d t n m)) (SDualBi (ConeG Cone Mlt p d t n m)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Duality

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalTransformable h (->) (SDualBi (ConeG ConeZeroHead Mlt p d t n m)) (SDualBi (ConeG Cone Mlt p d t n m)) Source # 
Instance details

Defined in OAlg.Limes.Cone.ZeroHead.Duality

Conic c => Natural r (->) (ConeG c s p d t n m) (ConeG Cone s p d t n m) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Core

Methods

roh :: Struct r x -> ConeG c s p d t n m x -> ConeG Cone s p d t n m x Source #

(HomDistributiveDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p), t ~ Dual (Dual t)) => ApplicativeG (SDualBi (ConeG Cone Dst p d t n m)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Duality

Methods

amapG :: h x y -> SDualBi (ConeG Cone Dst p d t n m) x -> SDualBi (ConeG Cone Dst p d t n m) y Source #

(HomMultiplicativeDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p), t ~ Dual (Dual t)) => ApplicativeG (SDualBi (ConeG Cone Mlt p d t n m)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Duality

Methods

amapG :: h x y -> SDualBi (ConeG Cone Mlt p d t n m) x -> SDualBi (ConeG Cone Mlt p d t n m) y Source #

(HomDistributiveDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (ConeG ConeZeroHead s p d t n m)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Cone.ZeroHead.Duality

Methods

amapG :: h x y -> SDualBi (ConeG ConeZeroHead s p d t n m) x -> SDualBi (ConeG ConeZeroHead s p d t n m) y Source #

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p), t ~ Dual (Dual t)) => FunctorialG (SDualBi (ConeG Cone Dst p d t n m)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Duality

(HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p), t ~ Dual (Dual t)) => FunctorialG (SDualBi (ConeG Cone Mlt p d t n m)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Duality

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (ConeG ConeZeroHead s p d t n m)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Cone.ZeroHead.Duality

(CategoryDisjunctive h, HomSlicedDistributive i h, FunctorialOriented h, p ~ Dual (Dual p), t ~ Dual (Dual t)) => ApplicativeG (SDualBi (ConeG (LiftableCone i) s p d t n m)) (Inv2 h) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Liftable

Methods

amapG :: Inv2 h x y -> SDualBi (ConeG (LiftableCone i) s p d t n m) x -> SDualBi (ConeG (LiftableCone i) s p d t n m) y Source #

(CategoryDisjunctive h, HomSlicedDistributive i h, FunctorialOriented h, p ~ Dual (Dual p), t ~ Dual (Dual t)) => FunctorialG (SDualBi (ConeG (LiftableCone i) s p d t n m)) (Inv2 h) (->) Source # 
Instance details

Defined in OAlg.Entity.Slice.Liftable

(CategoryDisjunctive h, HomSlicedDistributive i h, FunctorialOriented h, p ~ Dual (Dual p), t ~ Dual (Dual t), s ~ Dst) => NaturalTransformable (Inv2 h) (->) (SDualBi (ConeG (LiftableCone i) s p Diagram t n m)) (SDualBi (ConeG Cone s p Diagram t n m)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Liftable

Show (c s p d t n m x) => Show (ConeG c s p d t n m x) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Core

Methods

showsPrec :: Int -> ConeG c s p d t n m x -> ShowS #

show :: ConeG c s p d t n m x -> String #

showList :: [ConeG c s p d t n m x] -> ShowS #

Eq (c s p d t n m x) => Eq (ConeG c s p d t n m x) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Core

Methods

(==) :: ConeG c s p d t n m x -> ConeG c s p d t n m x -> Bool #

(/=) :: ConeG c s p d t n m x -> ConeG c s p d t n m x -> Bool #

type Dual1 (ConeG c s p d t n m :: Type -> Type) Source # 
Instance details

Defined in OAlg.Limes.Cone.Conic.Core

type Dual1 (ConeG c s p d t n m :: Type -> Type) = ConeG c s (Dual p) d (Dual t) n m

Natural

class (Conic c, HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammatic h d t n m, NaturalTransformable h (->) (SDualBi (ConeG c s p d t n m)) (SDualBi (ConeG Cone s p d t n m)), p ~ Dual (Dual p)) => NaturalConic (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') Source #

natural transformation for Conic objects from SDualBi (ConeG c s p d t n m) to SDualBi (Cone s p d t n m).

crohS :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. Conic c => SDualBi (ConeG c s p d t n m) x -> SDualBi (ConeG Cone s p d t n m) x Source #

natural assocition induced by croh betewwn SDualBi (ConeG c s p d t n m) and SDualBi (Cone s p d t n m).