oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Cone.Duality

Description

definition of duality for Cones over Diagrammatic objects.

Synopsis

Map

cnMapS :: forall s h (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') (p :: Perspective) x y. (HomD s h, NaturalDiagrammatic h d t n m, NaturalDiagrammatic h d (Dual t) n m, p ~ Dual (Dual p)) => h x y -> SDualBi (Cone s p d t n m) x -> SDualBi (Cone s p d t n m) y Source #

mapping of Cone.

Covariant

cnMapCov :: forall s (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomD s h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone s p d t n m x -> Cone s p d t n m y Source #

covariant mapping of Cone.

cnMapMltCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomMultiplicativeDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone Mlt p d t n m x -> Cone Mlt p d t n m y Source #

mapping of a cone under a Multiplicative covariant homomorphism.

cnMapDstCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone Dst p d t n m x -> Cone Dst p d t n m y Source #

mapping of a cone under a Distributive covariant homomorphism.

cnMap :: forall s h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (Hom s h, t ~ Dual (Dual t)) => h x y -> Cone s p Diagram t n m x -> Cone s p Diagram t n m y Source #

mapping of a cone under a s homomorphism.

cnMapMlt :: forall h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (HomMultiplicative h, t ~ Dual (Dual t)) => h x y -> Cone Mlt p Diagram t n m x -> Cone Mlt p Diagram t n m y Source #

mapping of a cone under a Multiplicative homomorphism.

cnMapDst :: forall h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (HomDistributive h, t ~ Dual (Dual t)) => h x y -> Cone Dst p Diagram t n m x -> Cone Dst p Diagram t n m y Source #

mapping of a cone under a Distributive homomorphism.

Contravariant

cnMapCnt :: forall s (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomD s h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone s p d t n m x -> Dual1 (Cone s p d t n m) y Source #

mapping of a cone under a contravariant homomorphism.

cnMapMltCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomMultiplicativeDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone Mlt p d t n m x -> Dual1 (Cone Mlt p d t n m) y Source #

mapping of a cone under a Multiplicative contravariant homomorphism.

cnMapDstCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone Dst p d t n m x -> Dual1 (Cone Dst p d t n m) y Source #

mapping of a cone under a Distributive contravariant homomorphism.

Orphan instances

(Eq x, EqPoint x) => EqDual1 (Cone s p Diagram t n m :: Type -> Type) (x :: Type) Source # 
Instance details

(Show x, ShowPoint x) => ShowDual1 (Cone s p Diagram t n m :: Type -> Type) (x :: Type) Source # 
Instance details

(HomDistributiveDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (Cone Dst p d t n m)) h (->) Source # 
Instance details

Methods

amapG :: h x y -> SDualBi (Cone Dst p d t n m) x -> SDualBi (Cone Dst p d t n m) y Source #

(HomMultiplicativeDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (Cone Mlt p d t n m)) h (->) Source # 
Instance details

Methods

amapG :: h x y -> SDualBi (Cone Mlt p d t n m) x -> SDualBi (Cone Mlt p d t n m) y Source #

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (Cone Dst p d t n m)) h (->) Source # 
Instance details

(HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (Cone Mlt p d t n m)) h (->) Source # 
Instance details