oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Cone.FactorChain

Contents

Description

predicate for a factor with end point at the starting point of a given chain.

Synopsis

Chain

data FactorChain (d :: DiagramType -> N' -> N' -> Type -> Type) (s :: Site) (n :: N') x Source #

predicate for a factor with end point at the starting point of the given chain.

Property

  1. Let FactorChain f d be in FactorChain To n a for a Multiplicative structure a then holds: end f == chnToStart (diagram d).
  2. Let FactorChain f d be in FactorChain From n a for a Multiplicative structure a then holds: end f == chnFromStart (diagram d).

Constructors

FactorChain x (d ('Chain s) (n + 1) n x) 

Instances

Instances details
(Show x, ShowPoint x) => Show (FactorChain Diagram s n x) Source # 
Instance details

Defined in OAlg.Limes.Cone.FactorChain

(Eq x, EqPoint x) => Eq (FactorChain Diagram s n x) Source # 
Instance details

Defined in OAlg.Limes.Cone.FactorChain

Methods

(==) :: FactorChain Diagram s n x -> FactorChain Diagram s n x -> Bool #

(/=) :: FactorChain Diagram s n x -> FactorChain Diagram s n x -> Bool #

(Diagrammatic d, Oriented x) => Validable (FactorChain d 'From n x) Source # 
Instance details

Defined in OAlg.Limes.Cone.FactorChain

Methods

valid :: FactorChain d 'From n x -> Statement Source #

(Diagrammatic d, Oriented x) => Validable (FactorChain d 'To n x) Source # 
Instance details

Defined in OAlg.Limes.Cone.FactorChain

Methods

valid :: FactorChain d 'To n x -> Statement Source #

cnPrjChainTo :: forall (d :: DiagramType -> N' -> N' -> Type -> Type) x (n :: N'). (Diagrammatic d, Multiplicative x) => FactorChain d 'To n x -> Cone Mlt 'Projective d ('Chain 'To) (n + 1) n x Source #

the induced Projective cone with ending factor given by the given FactorChain.

Property Let h = FactorChain f d be in FactorChain To n a for a Multiplicative structure a and ConeProjective d' _ (_:|..:|c:|Nil) = cnPrjChainTo h then holds: d' == d and c == f.

cnPrjChainToInv :: forall (d :: DiagramType -> N' -> N' -> Type -> Type) (n :: N') x. Cone Mlt 'Projective d ('Chain 'To) (n + 1) n x -> FactorChain d 'To n x Source #

the underlying factor chain of a projective chain to cone, i.e the inverse of cnPrjChainToInv.

cnPrjChainFrom :: forall (d :: DiagramType -> N' -> N' -> Type -> Type) x (n :: N'). (Diagrammatic d, Multiplicative x) => FactorChain d 'From n x -> Cone Mlt 'Projective d ('Chain 'From) (n + 1) n x Source #

the induced Projective cone with starting factor given by the given FactorChain.

Property Let h = FactorChain f d be in FactorChain From n a for a Multiplicative structure a and ConeProjective d' _ (c:|_) = cnPrjChainFrom h then holds: d' == d and c == f.

cnPrjChainFromInv :: forall (d :: DiagramType -> N' -> N' -> Type -> Type) (n :: N') x. Cone Mlt 'Projective d ('Chain 'From) (n + 1) n x -> FactorChain d 'From n x Source #

the underlying factor chain of a projective chain from cone, i.e. the inverse of cnPrjChainFrom.