| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Cone.ZeroHead.Core
Description
basice definitions a Cone with a first zero arrow.
Synopsis
- data ConeZeroHead s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where
- ConeZeroHead :: forall x s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m1 :: N'). Distributive x => Cone s p d t n (m1 + 1) x -> ConeZeroHead s p d t n (m1 + 1) x
Documentation
data ConeZeroHead s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where Source #
predicate for cones where the first arrow of its underlying diagram is equal to zero.
Constructors
| ConeZeroHead :: forall x s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m1 :: N'). Distributive x => Cone s p d t n (m1 + 1) x -> ConeZeroHead s p d t n (m1 + 1) x |