oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Cone.ZeroHead.Duality

Description

duality for ConeZeroHead.

Synopsis

Mapp

czMapS :: forall h (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') (p :: Perspective) x y s. (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m, NaturalDiagrammatic h d (Dual t) n m, p ~ Dual (Dual p)) => h x y -> SDualBi (ConeZeroHead s p d t n m) x -> SDualBi (ConeZeroHead s p d t n m) y Source #

mapping of ConeZeroHead

czMapCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y s (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> ConeZeroHead s p d t n m x -> ConeZeroHead s p d t n m y Source #

covariant mapping of ConeZeroHead

czMapCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y s (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> ConeZeroHead s p d t n m x -> Dual1 (ConeZeroHead s p d t n m) y Source #

contravariant mapping of ConeZeroHead

Orphan instances

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalConic h ConeZeroHead Mlt p d t n m Source # 
Instance details

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalTransformable h (->) (SDualBi (ConeG ConeZeroHead Mlt p d t n m)) (SDualBi (ConeG Cone Mlt p d t n m)) Source # 
Instance details

(HomDistributiveDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (ConeG ConeZeroHead s p d t n m)) h (->) Source # 
Instance details

Methods

amapG :: h x y -> SDualBi (ConeG ConeZeroHead s p d t n m) x -> SDualBi (ConeG ConeZeroHead s p d t n m) y Source #

(HomDistributiveDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (ConeZeroHead s p d t n m)) h (->) Source # 
Instance details

Methods

amapG :: h x y -> SDualBi (ConeZeroHead s p d t n m) x -> SDualBi (ConeZeroHead s p d t n m) y Source #

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (ConeG ConeZeroHead s p d t n m)) h (->) Source # 
Instance details

(HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (ConeZeroHead s p d t n m)) h (->) Source # 
Instance details