oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Definition.Duality

Description

duality of a Limes over a Diagrammatic object yielding a Conic object.

Synopsis

Mapping

lmMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (LimesG c s p d t n m) x -> SDualBi (LimesG c s p d t n m) y Source #

mapping of LimesG

lmMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConic (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> LimesG c s p d t n m x -> LimesG c s p d t n m y Source #

covariant mapping of LimesG

lmMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConic (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> LimesG c s p d t n m x -> LimesG c s (Dual p) d (Dual t) n m y Source #

contravariant mapping of LimesG

Orphan instances

NaturalConicBi (Inv2 h) c s p d t n m => ApplicativeG (SDualBi (LimesG c s p d t n m)) (Inv2 h) (->) Source # 
Instance details

Methods

amapG :: Inv2 h x y -> SDualBi (LimesG c s p d t n m) x -> SDualBi (LimesG c s p d t n m) y Source #

NaturalConicBi (Inv2 h) c s p d t n m => FunctorialG (SDualBi (LimesG c s p d t n m)) (Inv2 h) (->) Source # 
Instance details