oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Exact.Free

Description

deviation for free chains.

Synopsis

Variance

type VarianceFreeLiftable (t :: Site) = VarianceG t (ConicFreeTip Cone) ConeLiftable SomeFreeSliceDiagram Source #

variance according to the conic objects ConicFreeTip Cone, ConeLiftable over the diagrammatic object SomeFreeSliceDiagram.

Free Consecutive Zero

data ConsecutiveZeroFree (t :: Site) (n :: N') x where Source #

consecutive zero chain, where the tail of the points are free.

Property Let ConsecutiveZeroFree c fs be in ConsecutiveZeroFree t n x, then holds:

  1. sfrPoint f == p for all (f,p) in fs `zip` tail (cnzPoints c).

Constructors

ConsecutiveZeroFree :: forall (t :: Site) (n :: N') x. ConsecutiveZero t n x -> FinList (n + 2) (SomeFree x) -> ConsecutiveZeroFree t n x 

Instances

Instances details
(HomDistributiveDisjunctive h, HomOrientedSlicedFree h, t ~ Dual (Dual t)) => ApplicativeG (SDualBi (ConsecutiveZeroFree t n)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Exact.Free

Methods

amapG :: h x y -> SDualBi (ConsecutiveZeroFree t n) x -> SDualBi (ConsecutiveZeroFree t n) y Source #

(HomDistributiveDisjunctive h, FunctorialOriented h, HomOrientedSlicedFree h, t ~ Dual (Dual t)) => FunctorialG (SDualBi (ConsecutiveZeroFree t n)) h (->) Source # 
Instance details

Defined in OAlg.Limes.Exact.Free

(Show x, ShowPoint x) => Show (ConsecutiveZeroFree t n x) Source # 
Instance details

Defined in OAlg.Limes.Exact.Free

(Eq x, EqPoint x) => Eq (ConsecutiveZeroFree t n x) Source # 
Instance details

Defined in OAlg.Limes.Exact.Free

Distributive x => Validable (ConsecutiveZeroFree t n x) Source # 
Instance details

Defined in OAlg.Limes.Exact.Free

type Dual1 (ConsecutiveZeroFree t n :: Type -> Type) Source # 
Instance details

Defined in OAlg.Limes.Exact.Free

Duality

cnzFreeMapS :: forall h (t :: Site) x y (n :: N'). (HomDistributiveDisjunctive h, HomOrientedSlicedFree h, t ~ Dual (Dual t)) => h x y -> SDualBi (ConsecutiveZeroFree t n) x -> SDualBi (ConsecutiveZeroFree t n) y Source #

cnzFreeMapCov :: forall (h :: Type -> Type -> Type) x y (t :: Site) (n :: N'). (HomDistributiveDisjunctive h, HomOrientedSlicedFree h) => Variant2 'Covariant h x y -> ConsecutiveZeroFree t n x -> ConsecutiveZeroFree t n y Source #

covairaint mapping of ConsecutiveZeroFree.

cnzFreeMapCnt :: forall (h :: Type -> Type -> Type) x y (t :: Site) (n :: N'). (HomDistributiveDisjunctive h, HomOrientedSlicedFree h) => Variant2 'Contravariant h x y -> ConsecutiveZeroFree t n x -> ConsecutiveZeroFree (Dual t) n y Source #

contravaraint mapping of ConsecutiveZeroFree.

Proposition

prpConsecutiveZeroFree :: forall x (t :: Site) (n :: N'). Distributive x => ConsecutiveZeroFree t n x -> Statement Source #

validity according to ConsecutiveZeroFree.