oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Exact.ZeroPoint

Description

zero points within a Distributive structure.

Synopsis

Zero Point

newtype ZeroPoint x Source #

predicate for a zero point within a Distributive structure x.

Property Let ZeroPoint z be in ZeroPoint x within a Distributive structure x, then holds:

  1. zero (z :> z) == one z,

Constructors

ZeroPoint (Point x) 

Instances

Instances details
ShowPoint x => Show (ZeroPoint x) Source # 
Instance details

Defined in OAlg.Limes.Exact.ZeroPoint

EqPoint x => Eq (ZeroPoint x) Source # 
Instance details

Defined in OAlg.Limes.Exact.ZeroPoint

Methods

(==) :: ZeroPoint x -> ZeroPoint x -> Bool #

(/=) :: ZeroPoint x -> ZeroPoint x -> Bool #

Distributive x => Validable (ZeroPoint x) Source # 
Instance details

Defined in OAlg.Limes.Exact.ZeroPoint

isZeroPoint :: Distributive x => q x -> Point x -> Bool Source #

testing of being a zero point accroding to the given proxy type.

Limes

zrPointTerminal :: Distributive x => ZeroPoint x -> TerminalPoint x Source #

a zero point as terminal point.

zrPointTerminals :: Distributive x => ZeroPoint x -> Terminals x Source #

the induced terminals.

zrPointInitial :: Distributive x => ZeroPoint x -> InitialPoint x Source #

a zero point as initial point.

zrPointInitials :: Distributive x => ZeroPoint x -> Initials x Source #

the induced initials.