oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Limits.Core

Description

basic definition for a LimesG of diagrammatic object.

Synopsis

Limits

limes :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) d (t :: DiagramType) (n :: N') (m :: N') x. LimitsG c s p d t n m x -> d t n m x -> LimesG c s p d t n m x Source #

the limes over the given diagram.

newtype LimitsG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x Source #

limes of a diagrammatic object, i.e. assigning to each diagrammatic object d a limes over the d.

Property Let l be in LimitsG c s p d t n m x for a Conic c and a Diagrammatic d, then holds:

  1. diagram . cone . universalCone . limes l .=. diagram.

Constructors

LimitsG (d t n m x -> LimesG c s p d t n m x) 

Instances

Instances details
NaturalConicBi (Inv2 h) c s p d t n m => ApplicativeG (SDualBi (LimitsG c s p d t n m)) (Inv2 h) (->) Source # 
Instance details

Defined in OAlg.Limes.Limits.Duality

Methods

amapG :: Inv2 h x y -> SDualBi (LimitsG c s p d t n m) x -> SDualBi (LimitsG c s p d t n m) y Source #

NaturalConicBi (Inv2 h) c s p d t n m => FunctorialG (SDualBi (LimitsG c s p d t n m)) (Inv2 h) (->) Source # 
Instance details

Defined in OAlg.Limes.Limits.Duality

(Conic c, Diagrammatic d, XStandardEligibleConeG c s p d t n m x, XStandardEligibleConeFactorG c s p d t n m x, XStandard (d t n m x), Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => Validable (LimitsG c s p d t n m x) Source # 
Instance details

Defined in OAlg.Limes.Limits.Proposition

Methods

valid :: LimitsG c s p d t n m x -> Statement Source #

type Dual1 (LimitsG c s p d t n m :: Type -> Type) Source # 
Instance details

Defined in OAlg.Limes.Limits.Duality

type Dual1 (LimitsG c s p d t n m :: Type -> Type) = LimitsG c s (Dual p) d (Dual t) n m

type Limits s (p :: Perspective) = LimitsG Cone s p Diagram Source #

limits for Cones over Diagrams.

limesCone :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) d (t :: DiagramType) (n :: N') (m :: N') x. Conic c => LimitsG c s p d t n m x -> d t n m x -> LimesG Cone s p d t n m x Source #

the underlying limes according to Cone , given by a diagrammatic object of d t n m x.

limitsCone :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. Conic c => LimitsG c s p d t n m x -> LimitsG Cone s p d t n m x Source #

the underlying limits according to Cone.

Constructions

lmsMltPrjOrnt :: forall p (t :: DiagramType) (n :: N') (m :: N'). Entity p => p -> Limits Mlt 'Projective t n m (Orientation p) Source #

projective limits for Multiplicative structures over Orientation p .

lmsMltInjOrnt :: forall p (t :: DiagramType) (n :: N') (m :: N'). Entity p => p -> Limits Mlt 'Injective t n m (Orientation p) Source #

injective limits for Multiplicative structures over Orientation p.