oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Limes.Limits.Duality

Description

duality for LimitsG.

Synopsis

Mapp

lmsMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (LimitsG c s p d t n m) x -> SDualBi (LimitsG c s p d t n m) y Source #

mapping for LimitsG.

lmsMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> LimitsG c s p d t n m x -> LimitsG c s p d t n m y Source #

covariant mapping for LimitsG.

lmsMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> LimitsG c s p d t n m x -> Dual1 (LimitsG c s p d t n m) y Source #

contravariant mapping for LimitsG.

Orphan instances

NaturalConicBi (Inv2 h) c s p d t n m => ApplicativeG (SDualBi (LimitsG c s p d t n m)) (Inv2 h) (->) Source # 
Instance details

Methods

amapG :: Inv2 h x y -> SDualBi (LimitsG c s p d t n m) x -> SDualBi (LimitsG c s p d t n m) y Source #

NaturalConicBi (Inv2 h) c s p d t n m => FunctorialG (SDualBi (LimitsG c s p d t n m)) (Inv2 h) (->) Source # 
Instance details