| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Structure.Additive.Definition
Description
additive structures, i.e. structures with a partially defined addition (.+)
Synopsis
- class Fibred a => Additive a where
- zero' :: Additive a => p a -> Root a -> a
- data Add
- class (TransformableFbr s, Transformable s Add) => TransformableAdd s
- tauAdd :: Transformable s Add => Struct s x -> Struct Add x
- class Additive a => Abelian a where
- isZero :: Additive a => a -> Bool
- data Abl
- class (Transformable s Fbr, Transformable s Add, Transformable s Abl) => TransformableAbl s
- xSheaf :: Additive a => XStalk a -> N -> X (Sheaf a)
- xSheafRoot :: Additive a => XStalk a -> N -> Root a -> X (Sheaf a)
Additive
class Fibred a => Additive a where Source #
Fibred structures with a partialy defined addition and having
zero as the neutral element of the summation. An entity of a Additive
structure will be called a summand.
Properties Let a be a Additive structure, then holds:
- For all
rinholds:Roota.root(zeror)==r - For all
f,ginawithholds:rootf==rootgf.+g==g+f - For all
finaholds:f+zero(rootf)==f - For all
f,g,hinawithholds:rootf==rootg==rooth(f.+g)+h==f+(g+h) - For all
finaandninNholds:andntimes0 f ==zero(rootf).ntimes(n+1) f==f+ntimesn f
Methods
the neutral element associated to each root. If there is no ambiguity
for we will briefly denote it by zero r0 r or just 0.
(+) :: a -> a -> a infixl 6 Source #
the addition for two summands.
ntimes :: N -> a -> a Source #
n times of a summand.
Instances
type representing the class of Additive structures.
Instances
| TransformableAdd Add Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableTyp Add Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableFbr Add Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| Transformable Abl Add Source # | |
| Transformable Add Ent Source # | |
| Transformable Add Typ Source # | |
| Transformable Add Fbr Source # | |
| Transformable Dst Add Source # | |
| Transformable DstX Add Source # | |
| Transformable (Alg k) Add Source # | |
| Transformable (Vec k) Add Source # | |
| Transformable s Add => Transformable (s, SldFr) Add Source # | |
| Transformable s Add => Transformable (s, Sld i) Add Source # | |
| type Structure Add x Source # | |
Defined in OAlg.Structure.Additive.Definition | |
class (TransformableFbr s, Transformable s Add) => TransformableAdd s Source #
helper class to avoid undecidable instances.
Instances
| TransformableAdd Abl Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableAdd Add Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableAdd Dst Source # | |
Defined in OAlg.Structure.Distributive.Definition | |
| TransformableAdd DstX Source # | |
Defined in OAlg.Structure.Distributive.Proposition | |
| TransformableAdd (Alg k) Source # | |
Defined in OAlg.Structure.Algebraic.Definition | |
| TransformableAdd (Vec k) Source # | |
Defined in OAlg.Structure.Vectorial.Definition | |
| TransformableAdd s => TransformableAdd (s, SldFr) Source # | |
Defined in OAlg.Entity.Slice.Free | |
| TransformableAdd s => TransformableAdd (s, Sld i) Source # | |
Defined in OAlg.Entity.Slice.Sliced | |
Abelian
class Additive a => Abelian a where Source #
Additive structures having for each summand an additve inverse.
Properties Let a be a Additive structure, then holds:
Methods
negation of a summand.
(-) :: a -> a -> a infixl 6 Source #
subtraction of two summands.
Properties
ztimes :: Z -> a -> a Source #
z times of a sumand.
Instances
type representing the class of Abelian structures.
Instances
| TransformableAbl Abl Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableAdd Abl Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableTyp Abl Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| TransformableFbr Abl Source # | |
Defined in OAlg.Structure.Additive.Definition | |
| Transformable Abl Ent Source # | |
| Transformable Abl Add Source # | |
| Transformable Abl Typ Source # | |
| Transformable Abl Fbr Source # | |
| type Structure Abl x Source # | |
Defined in OAlg.Structure.Additive.Definition | |
class (Transformable s Fbr, Transformable s Add, Transformable s Abl) => TransformableAbl s Source #
transformable to Abelian structure.
Instances
| TransformableAbl Abl Source # | |
Defined in OAlg.Structure.Additive.Definition | |