oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellSafe-Inferred
LanguageHaskell2010

OAlg.Structure.Definition

Description

introducing the idiom of Structures as parameterized constraints.

Synopsis

Structure

type family Structure s x Source #

parameterized constraint for a type x.

Instances

Instances details
type Structure EqE x Source # 
Instance details

Defined in OAlg.Data.Validable

type Structure EqE x = (Show x, Eq x, XStandard x)
type Structure XStd x Source # 
Instance details

Defined in OAlg.Data.Validable

type Structure Ent x Source # 
Instance details

Defined in OAlg.Entity.Definition

type Structure Ent x = Entity x
type Structure EntOrd x Source # 
Instance details

Defined in OAlg.Entity.Definition

type Structure EntOrd x = (Entity x, Ord x)
type Structure SldFr x Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

type Structure Abl x Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

type Structure Abl x = Abelian x
type Structure Add x Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

type Structure Bol x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure Bol x = Boolean x
type Structure Ord' x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure Ord' x = Ord x
type Structure Typ x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure Dst x Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

type Structure DstX x Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

type Structure Fbr x Source # 
Instance details

Defined in OAlg.Structure.Fibred.Definition

type Structure Fbr x = Fibred x
type Structure FbrOrt x Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

type Structure FbrOrtX x Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

type Structure Mlt x Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

type Structure MltX x Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

type Structure EqEOrt x Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

type Structure Ort x Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

type Structure OrtX x Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

type Structure OrtSiteX x Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

type Structure Type x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure Type x = ()
type Structure (Sld i) x Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

type Structure (Sld i) x = Sliced i x
type Structure (Alg k) x Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

type Structure (Alg k) x = (Algebraic x, k ~ Scalar x)
type Structure (Vec k) x Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

type Structure (Vec k) x = (Vectorial x, k ~ Scalar x)
type Structure (SubStruct t s) x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure (SubStruct t s) x = Structure t x
type Structure (s, t) x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure (s, t) x = (Structure s x, Structure t x)

data Struct s x where Source #

attest that the type x admits the constrains given by the parameter s.

Constructors

Struct :: forall s x. Structure s x => Struct s x 

Instances

Instances details
Transformable s Typ => TestEquality (Struct s :: Type -> Type) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

testEquality :: Struct s a -> Struct s b -> Maybe (a :~: b) #

Eq1 (Struct s) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

eq1 :: Struct s x -> Struct s x -> Bool Source #

Show1 (Struct s) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

show1 :: Struct s x -> String Source #

Singular (Struct s) Source # 
Instance details

Defined in OAlg.Structure.Definition

Validable1 (Struct s) Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

valid1 :: Struct s x -> Statement Source #

Show (Struct s x) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

showsPrec :: Int -> Struct s x -> ShowS #

show :: Struct s x -> String #

showList :: [Struct s x] -> ShowS #

Eq (Struct s x) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

(==) :: Struct s x -> Struct s x -> Bool #

(/=) :: Struct s x -> Struct s x -> Bool #

Validable (Struct s x) Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

valid :: Struct s x -> Statement Source #

tauTuple :: Struct s x -> Struct t x -> Struct (s, t) x Source #

the product structure.

tauFst :: Struct (s, t) x -> Struct s x Source #

the first struct according to (s,t).

tauSnd :: Struct (s, t) x -> Struct t x Source #

the second struct according to (s,t).

type family Structure2 m x y Source #

parameterized constraint for a two types x and y.

data Struct2 m x y where Source #

attest that the two types x and y admit the constraint given by the parameter s.

Constructors

Struct2 :: forall m x y. Structure2 m x y => Struct2 m x y 

Instances

Instances details
Eq2 (Struct2 m) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

eq2 :: Struct2 m x y -> Struct2 m x y -> Bool Source #

Show2 (Struct2 m) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

show2 :: Struct2 m a b -> String Source #

Validable2 (Struct2 m) Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

valid2 :: Struct2 m x y -> Statement Source #

Show (Struct2 m x y) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

showsPrec :: Int -> Struct2 m x y -> ShowS #

show :: Struct2 m x y -> String #

showList :: [Struct2 m x y] -> ShowS #

Eq (Struct2 m x y) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

(==) :: Struct2 m x y -> Struct2 m x y -> Bool #

(/=) :: Struct2 m x y -> Struct2 m x y -> Bool #

Validable (Struct2 m x y) Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

valid :: Struct2 m x y -> Statement Source #

Transformable

class Transformable s t where Source #

transforming structural attests.

Methods

tau :: Struct s x -> Struct t x Source #

Instances

Instances details
Transformable EqE Type Source # 
Instance details

Defined in OAlg.Data.Validable

Methods

tau :: Struct EqE x -> Struct Type x Source #

Transformable Abl Ent Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Abl x -> Struct Ent x Source #

Transformable Abl Add Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Abl x -> Struct Add x Source #

Transformable Abl Typ Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Abl x -> Struct Typ x Source #

Transformable Abl Fbr Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Abl x -> Struct Fbr x Source #

Transformable Add Ent Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Add x -> Struct Ent x Source #

Transformable Add Typ Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Add x -> Struct Typ x Source #

Transformable Add Fbr Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Add x -> Struct Fbr x Source #

Transformable Dst Ent Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Ent x Source #

Transformable Dst Add Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Add x Source #

Transformable Dst Typ Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Typ x Source #

Transformable Dst Fbr Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Fbr x Source #

Transformable Dst FbrOrt Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct FbrOrt x Source #

Transformable Dst Mlt Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Mlt x Source #

Transformable Dst Ort Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Ort x Source #

Transformable Dst Type Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Type x Source #

Transformable DstX Add Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Add x Source #

Transformable DstX Typ Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Typ x Source #

Transformable DstX Dst Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Dst x Source #

Transformable DstX Fbr Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Fbr x Source #

Transformable DstX FbrOrt Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct FbrOrt x Source #

Transformable DstX Mlt Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Mlt x Source #

Transformable DstX Ort Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Ort x Source #

Transformable DstX Type Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Type x Source #

Transformable Fbr Ent Source # 
Instance details

Defined in OAlg.Structure.Fibred.Definition

Methods

tau :: Struct Fbr x -> Struct Ent x Source #

Transformable Fbr Typ Source # 
Instance details

Defined in OAlg.Structure.Fibred.Definition

Methods

tau :: Struct Fbr x -> Struct Typ x Source #

Transformable FbrOrt Ent Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Ent x Source #

Transformable FbrOrt Typ Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Typ x Source #

Transformable FbrOrt Fbr Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Fbr x Source #

Transformable FbrOrt Ort Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Ort x Source #

Transformable FbrOrt Type Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Type x Source #

Transformable FbrOrtX Typ Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Typ x Source #

Transformable FbrOrtX Fbr Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Fbr x Source #

Transformable FbrOrtX FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Transformable FbrOrtX Ort Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Ort x Source #

Transformable FbrOrtX Type Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Type x Source #

Transformable Mlt Ent Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tau :: Struct Mlt x -> Struct Ent x Source #

Transformable Mlt Typ Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tau :: Struct Mlt x -> Struct Typ x Source #

Transformable Mlt Ort Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tau :: Struct Mlt x -> Struct Ort x Source #

Transformable Mlt Type Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tau :: Struct Mlt x -> Struct Type x Source #

Transformable MltX Typ Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

tau :: Struct MltX x -> Struct Typ x Source #

Transformable MltX Mlt Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

tau :: Struct MltX x -> Struct Mlt x Source #

Transformable MltX Ort Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

tau :: Struct MltX x -> Struct Ort x Source #

Transformable MltX Type Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

tau :: Struct MltX x -> Struct Type x Source #

Transformable EqEOrt Type Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct EqEOrt x -> Struct Type x Source #

Transformable Ort Ent Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct Ort x -> Struct Ent x Source #

Transformable Ort Typ Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct Ort x -> Struct Typ x Source #

Transformable Ort Type Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct Ort x -> Struct Type x Source #

Transformable OrtX XStd Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct OrtX x -> Struct XStd x Source #

Transformable OrtX Typ Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct OrtX x -> Struct Typ x Source #

Transformable OrtX EqEOrt Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct OrtX x -> Struct EqEOrt x Source #

Transformable OrtX Ort Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct OrtX x -> Struct Ort x Source #

Transformable OrtX Type Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct OrtX x -> Struct Type x Source #

Transformable OrtSiteX Typ Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

Methods

tau :: Struct OrtSiteX x -> Struct Typ x Source #

Transformable OrtSiteX Ort Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

Methods

tau :: Struct OrtSiteX x -> Struct Ort x Source #

Transformable OrtSiteX Type Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

Methods

tau :: Struct OrtSiteX x -> Struct Type x Source #

Transformable s s Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

tau :: Struct s x -> Struct s x Source #

Transformable t (SubStruct t s) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

tau :: Struct t x -> Struct (SubStruct t s) x Source #

Transformable (Alg k) Ent Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Ent x Source #

Transformable (Alg k) Add Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Add x Source #

Transformable (Alg k) Typ Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Typ x Source #

Transformable (Alg k) Dst Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Dst x Source #

Transformable (Alg k) Fbr Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Fbr x Source #

Transformable (Alg k) FbrOrt Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct FbrOrt x Source #

Transformable (Alg k) Mlt Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Mlt x Source #

Transformable (Alg k) Ort Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Ort x Source #

Transformable (Vec k) Ent Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Methods

tau :: Struct (Vec k) x -> Struct Ent x Source #

Transformable (Vec k) Add Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Methods

tau :: Struct (Vec k) x -> Struct Add x Source #

Transformable (Vec k) Typ Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Methods

tau :: Struct (Vec k) x -> Struct Typ x Source #

Transformable (Vec k) Fbr Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Methods

tau :: Struct (Vec k) x -> Struct Fbr x Source #

Transformable (Alg k) (Vec k) Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct (Vec k) x Source #

Transformable (s, SldFr) SldFr Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct SldFr x Source #

Transformable s Add => Transformable (s, SldFr) Add Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct Add x Source #

Transformable s Dst => Transformable (s, SldFr) Dst Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct Dst x Source #

Transformable s Fbr => Transformable (s, SldFr) Fbr Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct Fbr x Source #

Transformable s FbrOrt => Transformable (s, SldFr) FbrOrt Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct FbrOrt x Source #

Transformable s Mlt => Transformable (s, SldFr) Mlt Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct Mlt x Source #

Transformable s Ort => Transformable (s, SldFr) Ort Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct Ort x Source #

Transformable s Add => Transformable (s, Sld i) Add Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct Add x Source #

Transformable s Dst => Transformable (s, Sld i) Dst Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct Dst x Source #

Transformable s Fbr => Transformable (s, Sld i) Fbr Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct Fbr x Source #

Transformable s FbrOrt => Transformable (s, Sld i) FbrOrt Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct FbrOrt x Source #

Transformable s Mlt => Transformable (s, Sld i) Mlt Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct Mlt x Source #

Transformable s Ort => Transformable (s, Sld i) Ort Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct Ort x Source #

Transformable (s, Sld i) Type Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct Type x Source #

Attestable k => Transformable (s, SldFr) (Sld (Free k)) Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct (Sld (Free k)) x Source #

Transformable (s, Sld i) (Sld i) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct (Sld i) x Source #

tauType :: Struct s x -> Struct Type x Source #

transformbing to Type-structure.

type Transformable1 (f :: Type -> Type) s = TransformableG f s s Source #

transforming structural attests.

tau1 :: Transformable1 f s => Struct s x -> Struct s (f x) Source #

transformation1. (needed for backward compatibility!).

class TransformableG (t :: Type -> Type) u v where Source #

transforming structural attests.

Methods

tauG :: Struct u x -> Struct v (t x) Source #

Instances

Instances details
TransformableG Id OrtX EqE Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tauG :: Struct OrtX x -> Struct EqE (Id x) Source #

TransformableG Id OrtX EqEOrt Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tauG :: Struct OrtX x -> Struct EqEOrt (Id x) Source #

TransformableG Matrix Dst Dst Source # 
Instance details

Defined in OAlg.Entity.Matrix.Definition

Methods

tauG :: Struct Dst x -> Struct Dst (Matrix x) Source #

TransformableG Matrix DstX DstX Source # 
Instance details

Defined in OAlg.Entity.Matrix.Definition

Methods

tauG :: Struct DstX x -> Struct DstX (Matrix x) Source #

TransformableG Op Dst Dst Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tauG :: Struct Dst x -> Struct Dst (Op x) Source #

TransformableG Op DstX DstX Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tauG :: Struct DstX x -> Struct DstX (Op x) Source #

TransformableG Op FbrOrt FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tauG :: Struct FbrOrt x -> Struct FbrOrt (Op x) Source #

TransformableG Op FbrOrtX FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tauG :: Struct FbrOrtX x -> Struct FbrOrtX (Op x) Source #

TransformableG Op Mlt Mlt Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tauG :: Struct Mlt x -> Struct Mlt (Op x) Source #

TransformableG Op MltX MltX Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

tauG :: Struct MltX x -> Struct MltX (Op x) Source #

TransformableG Op EqEOrt EqEOrt Source # 
Instance details

Defined in OAlg.Structure.Oriented.Opposite

Methods

tauG :: Struct EqEOrt x -> Struct EqEOrt (Op x) Source #

TransformableG Op Ort Ort Source # 
Instance details

Defined in OAlg.Structure.Oriented.Opposite

Methods

tauG :: Struct Ort x -> Struct Ort (Op x) Source #

TransformableG Op OrtX OrtX Source # 
Instance details

Defined in OAlg.Structure.Oriented.Opposite

Methods

tauG :: Struct OrtX x -> Struct OrtX (Op x) Source #

TransformableG Op OrtSiteX OrtSiteX Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

TransformableG Pnt OrtX EqE Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tauG :: Struct OrtX x -> Struct EqE (Pnt x) Source #

TransformableG Pnt OrtX EqEOrt Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tauG :: Struct OrtX x -> Struct EqEOrt (Pnt x) Source #

TransformableG [] EntOrd EntOrd Source # 
Instance details

Defined in OAlg.Entity.Definition

Methods

tauG :: Struct EntOrd x -> Struct EntOrd [x] Source #

TransformableG d s Type Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

tauG :: Struct s x -> Struct Type (d x) Source #

(TransformableG d s u, TransformableG d s v) => TransformableG d s (u, v) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

tauG :: Struct s x -> Struct (u, v) (d x) Source #

TransformableG Op (Sld i) (Sld i) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tauG :: Struct (Sld i) x -> Struct (Sld i) (Op x) Source #

TransformableG Op (Alg k) (Alg k) Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tauG :: Struct (Alg k) x -> Struct (Alg k) (Op x) Source #

TransformableG Op (Dst, t) Dst Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tauG :: Struct (Dst, t) x -> Struct Dst (Op x) Source #

TransformableG Op (Mlt, t) Mlt Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tauG :: Struct (Mlt, t) x -> Struct Mlt (Op x) Source #

TransformableG Op (Ort, t) Ort Source # 
Instance details

Defined in OAlg.Structure.Oriented.Opposite

Methods

tauG :: Struct (Ort, t) x -> Struct Ort (Op x) Source #

TransformableG Op (s, Sld i) (Sld i) Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tauG :: Struct (s, Sld i) x -> Struct (Sld i) (Op x) Source #

(Attestable m, n ~ (m + 1)) => TransformableG (SDualBi (Diagram ('Chain 'From) n m)) OrtSiteX EqE Source # 
Instance details

Defined in OAlg.Entity.Diagram.Definition

Methods

tauG :: Struct OrtSiteX x -> Struct EqE (SDualBi (Diagram ('Chain 'From) n m) x) Source #

(Attestable m, n ~ (m + 1)) => TransformableG (SDualBi (Diagram ('Chain 'To) n m)) OrtSiteX EqE Source # 
Instance details

Defined in OAlg.Entity.Diagram.Definition

Methods

tauG :: Struct OrtSiteX x -> Struct EqE (SDualBi (Diagram ('Chain 'To) n m) x) Source #

tauG' :: TransformableG t u v => q t -> Struct u x -> Struct v (t x) Source #

prefixing a proxy.

Some Structure Types

data Typ Source #

type index for Typeable structures.

Instances

Instances details
Transformable Abl Typ Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Abl x -> Struct Typ x Source #

Transformable Add Typ Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Methods

tau :: Struct Add x -> Struct Typ x Source #

Transformable Dst Typ Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct Typ x Source #

Transformable DstX Typ Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct Typ x Source #

Transformable Fbr Typ Source # 
Instance details

Defined in OAlg.Structure.Fibred.Definition

Methods

tau :: Struct Fbr x -> Struct Typ x Source #

Transformable FbrOrt Typ Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Typ x Source #

Transformable FbrOrtX Typ Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Typ x Source #

Transformable Mlt Typ Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Methods

tau :: Struct Mlt x -> Struct Typ x Source #

Transformable MltX Typ Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Methods

tau :: Struct MltX x -> Struct Typ x Source #

Transformable Ort Typ Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct Ort x -> Struct Typ x Source #

Transformable OrtX Typ Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Methods

tau :: Struct OrtX x -> Struct Typ x Source #

Transformable OrtSiteX Typ Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

Methods

tau :: Struct OrtSiteX x -> Struct Typ x Source #

Transformable (Alg k) Typ Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct Typ x Source #

Transformable (Vec k) Typ Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Methods

tau :: Struct (Vec k) x -> Struct Typ x Source #

type Structure Typ x Source # 
Instance details

Defined in OAlg.Structure.Definition

data Ord' Source #

type index for ordered structures.

Instances

Instances details
ApplicativeG Set (Map Ord') (->) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Set

Methods

amapG :: Map Ord' x y -> Set x -> Set y Source #

FunctorialG Set (Map Ord') (->) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Set

type Structure Ord' x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure Ord' x = Ord x

data Bol Source #

type index for Boolean structures.

Instances

Instances details
type Structure Bol x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure Bol x = Boolean x

data SubStruct t s Source #

type index for parameterized sub structures.

Instances

Instances details
Transformable t (SubStruct t s) Source # 
Instance details

Defined in OAlg.Structure.Definition

Methods

tau :: Struct t x -> Struct (SubStruct t s) x Source #

type Structure (SubStruct t s) x Source # 
Instance details

Defined in OAlg.Structure.Definition

type Structure (SubStruct t s) x = Structure t x

tauGSubStruct :: TransformableG t u v => Struct (SubStruct u s) x -> Struct v (t x) Source #

generalized transformation of a sub structure.

tauSubStruct :: Struct (SubStruct t s) x -> Struct t x Source #

transforming a sub structure to its base.