oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Structure.FibredOriented

Description

definition of FibredOriented structures.

Synopsis

Fibred Oriented

class (Fibred d, Oriented d, Root d ~ Orientation (Point d)) => FibredOriented d Source #

Fibred and Oriented structure with matching root and orientation.

Property Let d be a FibredOriented structure, then holds:

  1. root .=. orientation.

Note FibredOriented structures are required for Distributive structures.

Instances

Instances details
FibredOriented N Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

FibredOriented Q Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

FibredOriented Z Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

FibredOriented N' Source # 
Instance details

Defined in OAlg.Entity.Natural

FibredOriented W' Source # 
Instance details

Defined in OAlg.Entity.Natural

FibredOriented Integer Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

FibredOriented () Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

FibredOriented Int Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

FibredOriented x => FibredOriented (Id x) Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

(Additive x, FibredOriented x) => FibredOriented (Matrix x) Source # 
Instance details

Defined in OAlg.Entity.Matrix.Definition

FibredOriented x => FibredOriented (Op x) Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Entity p => FibredOriented (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

(Semiring r, Commutative r, FibredOriented m) => FibredOriented (Sum r m) Source # 
Instance details

Defined in OAlg.Entity.Sum.Definition

(Semiring r, Commutative r, FibredOriented m) => FibredOriented (SumForm r m) Source # 
Instance details

Defined in OAlg.Entity.Sum.Definition

(Distributive x, Typeable t, Typeable n) => FibredOriented (ConsecutiveZeroHom t n x) Source # 
Instance details

Defined in OAlg.Limes.Exact.ConsecutiveZero

(Distributive a, Typeable t, Typeable n, Typeable m) => FibredOriented (DiagramTrafo t n m a) Source # 
Instance details

Defined in OAlg.Entity.Diagram.Transformation

data FbrOrt Source #

type representing the class of FibredOriented structures.

Instances

Instances details
TransformableTyp FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableFbr FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableFbrOrt FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableOrt FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableOp FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Transformable Dst FbrOrt Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Methods

tau :: Struct Dst x -> Struct FbrOrt x Source #

Transformable DstX FbrOrt Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Methods

tau :: Struct DstX x -> Struct FbrOrt x Source #

Transformable FbrOrt Ent Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Ent x Source #

Transformable FbrOrt Typ Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Typ x Source #

Transformable FbrOrt Fbr Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Fbr x Source #

Transformable FbrOrt Ort Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Ort x Source #

Transformable FbrOrt Type Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrt x -> Struct Type x Source #

Transformable FbrOrtX FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableGRefl Op FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableG Op FbrOrt FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tauG :: Struct FbrOrt x -> Struct FbrOrt (Op x) Source #

Transformable (Alg k) FbrOrt Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Methods

tau :: Struct (Alg k) x -> Struct FbrOrt x Source #

Transformable s FbrOrt => Transformable (s, SldFr) FbrOrt Source # 
Instance details

Defined in OAlg.Entity.Slice.Free

Methods

tau :: Struct (s, SldFr) x -> Struct FbrOrt x Source #

Transformable s FbrOrt => Transformable (s, Sld i) FbrOrt Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

Methods

tau :: Struct (s, Sld i) x -> Struct FbrOrt x Source #

type Structure FbrOrt x Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

X

xoFbrOrt :: XOrtOrientation f -> XFbrOrt f Source #

the associated random variable for validation FibredOriented structures.

xFbrOrtOrnt :: X p -> XFbrOrt (Orientation p) Source #

random variable for the FibredOriented structure of Orientation p.

type XFbrOrt = X Source #

random variable type for validating FibredOriented structures.

data FbrOrtX Source #

type representing the class FibredOriented equipped with standard random variables.

Instances

Instances details
TransformableType FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableFbr FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableFbrOrt FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableOrt FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

TransformableOp FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Transformable FbrOrtX Typ Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Typ x Source #

Transformable FbrOrtX Fbr Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Fbr x Source #

Transformable FbrOrtX FbrOrt Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Transformable FbrOrtX Ort Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Ort x Source #

Transformable FbrOrtX Type Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tau :: Struct FbrOrtX x -> Struct Type x Source #

TransformableG Op FbrOrtX FbrOrtX Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Methods

tauG :: Struct FbrOrtX x -> Struct FbrOrtX (Op x) Source #

type Structure FbrOrtX x Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Proposition

prpFbrOrt :: FibredOriented f => XFbrOrt f -> Statement Source #

validity for FibredOriented structures.

Orphan instances

FibredOriented f => Dualisable (Sheaf f) Source # 
Instance details

Methods

toDual :: Sheaf f -> Dual (Sheaf f) Source #

fromDual :: Dual (Sheaf f) -> Sheaf f Source #

FibredOriented x => Fibred (Op x) Source # 
Instance details

Methods

root :: Op x -> Root (Op x) Source #