oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Structure.Lattice.Definition

Description

lattices

Synopsis

Documentation

class (PartiallyOrdered a, Logical a) => Lattice a Source #

lattices on partially orderd sets.

Properties Let a be an instance of Lattice, then holds:

  1. For all x and y in a holds:

    1. x <<= (x || y) and y <<= (x || y).
    2. For all z with x <<= z and y <<= z holds: (x || y) <<= z.
  2. For all x and y in a holds:

    1. x && y <<= x and x && y <<= y
    2. For all z with z <<= x and z <<= y holds: z <<= (x && y) .

Instances

Instances details
Lattice Bool Source # 
Instance details

Defined in OAlg.Structure.Lattice.Definition

Ord x => Lattice (Set x) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Set

Lattice a => Lattice (Op a) Source # 
Instance details

Defined in OAlg.Structure.Lattice.Definition

(Ord a, Ord b) => Lattice (Graph a (Set b)) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Graph