oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Structure.Oriented.Orientation

Description

defining a orientation on a type.

Synopsis

Orientation

data Orientation p Source #

orientation given by the start point as its first component and the end point as its second.

Property For all o in Orientation p holds: o == start o :> end o.

Note As Orientations are instances of almost all algebraic structures defined here, they serve as a proof that this structures are instanceable.

Constructors

p :> p infix 5 

Instances

Instances details
(Conic c, Diagrammatic d, XStandard x) => XStandardEligibleConeFactorG c s p d t n m (Orientation x) Source # 
Instance details

Defined in OAlg.Limes.Definition.Proposition

(Conic c, Diagrammatic d, XStandard x) => XStandardEligibleConeG c s p d t n m (Orientation x) Source # 
Instance details

Defined in OAlg.Limes.Definition.Proposition

XStandard p => XStandardEligibleConeCokernel n (Orientation p) Source # 
Instance details

Defined in OAlg.Limes.KernelsAndCokernels

XStandard p => XStandardEligibleConeFactorCokernel n (Orientation p) Source # 
Instance details

Defined in OAlg.Limes.KernelsAndCokernels

XStandard p => XStandardEligibleConeFactorKernel n (Orientation p) Source # 
Instance details

Defined in OAlg.Limes.KernelsAndCokernels

XStandard p => XStandardEligibleConeKernel n (Orientation p) Source # 
Instance details

Defined in OAlg.Limes.KernelsAndCokernels

XStandard p => XStandardOrtSite 'From (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

XStandard p => XStandardOrtSite 'To (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

ApplicativeG Orientation (->) (->) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Methods

amapG :: (x -> y) -> Orientation x -> Orientation y Source #

XStandardOrtSite 'From (SliceFactor 'To (Proxy :: Type -> Type) OS) Source # 
Instance details

Defined in OAlg.Entity.Slice.Definition

Show p => Show (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Eq p => Eq (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Ord p => Ord (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Transposable (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Singleton u => Singleton (Orientation u) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Methods

unit :: Orientation u Source #

Validable p => Validable (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

XStandard p => XStandard (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Entity p => Abelian (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

Entity p => Additive (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Additive.Definition

(Entity p, XStandard p) => XStandardAdd (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Additive.Proposition

Entity p => Algebraic (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Algebraic.Definition

Entity p => Distributive (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

Entity p => TransposableDistributive (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Distributive.Definition

(Entity p, XStandard p) => XStandardDst (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Distributive.Proposition

Entity p => Real (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Exponential

Methods

power :: Number r => Orientation p -> r -> Orientation p Source #

Entity p => Fibred (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Definition

Eq p => EqRoot (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

Show p => ShowRoot (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

Singleton p => SingletonRoot (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

Typeable p => TypeableRoot (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

Validable p => ValidableRoot (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

XStandard p => XStandardRoot (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

Entity p => FibredOriented (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.FibredOriented

Entity p => Cayleyan (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Entity p => Invertible (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Entity p => Multiplicative (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

Entity p => TransposableMultiplicative (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Definition

(Entity p, XStandard p) => XStandardMlt (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Multiplicative.Proposition

Entity p => Oriented (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Entity p => TransposableOriented (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Definition

Eq x => EqPoint (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Ord x => OrdPoint (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Show x => ShowPoint (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Singleton x => SingletonPoint (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Typeable x => TypeablePoint (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

Validable x => ValidablePoint (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

XStandard p => XStandardPoint (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

XStandard p => XStandardOrtOrientation (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

XStandard p => XStandardOrtSiteFrom (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

XStandard p => XStandardOrtSiteTo (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Oriented.X

Entity p => Euclidean (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Entity p => Vectorial (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

Associated Types

type Scalar (Orientation p) 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

type Scalar (Orientation p) = Q
Sliced (Proxy :: Type -> Type) OS Source # 
Instance details

Defined in OAlg.Entity.Slice.Sliced

XStandardOrtSiteFrom (SliceFactor 'To (Proxy :: Type -> Type) OS) Source # 
Instance details

Defined in OAlg.Entity.Slice.Definition

(Entity p, t ~ 'Parallel 'RightToLeft, n ~ N2, Diagrammatic d, XStandard p, XStandard (d t n m (Orientation p))) => XStandard (Cone Dst 'Injective d t n m (Orientation p)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Definition

Methods

xStandard :: X (Cone Dst 'Injective d t n m (Orientation p)) Source #

(Entity p, t ~ 'Parallel 'LeftToRight, n ~ N2, Diagrammatic d, XStandard p, XStandard (d t n m (Orientation p))) => XStandard (Cone Dst 'Projective d t n m (Orientation p)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Definition

Methods

xStandard :: X (Cone Dst 'Projective d t n m (Orientation p)) Source #

(Entity p, Diagrammatic d, XStandard p, XStandard (d t n m (Orientation p))) => XStandard (Cone Mlt 'Injective d t n m (Orientation p)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Definition

Methods

xStandard :: X (Cone Mlt 'Injective d t n m (Orientation p)) Source #

(Entity p, Diagrammatic d, XStandard p, XStandard (d t n m (Orientation p))) => XStandard (Cone Mlt 'Projective d t n m (Orientation p)) Source # 
Instance details

Defined in OAlg.Limes.Cone.Definition

Methods

xStandard :: X (Cone Mlt 'Projective d t n m (Orientation p)) Source #

type Root (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Fibred.Root

type Point (Orientation x) Source # 
Instance details

Defined in OAlg.Structure.Oriented.Orientation

type Point (Orientation x) = x
type Scalar (Orientation p) Source # 
Instance details

Defined in OAlg.Structure.Vectorial.Definition

type Scalar (Orientation p) = Q

opposite :: Orientation p -> Orientation p Source #

the opposite orientation.

type OS = Orientation Symbol Source #

as Orientation p is an instance of almost every structured class it serves as a standard type for validating.

Applicative

omap :: ApplicativePoint h => h a b -> Orientation (Point a) -> Orientation (Point b) Source #

the induced mapping of Orientation.