| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Structure.Oriented.Proposition
Contents
Description
Propositions on Oriented structure.
Synopsis
- prpOrt :: Oriented q => XOrt q -> Statement
- type XOrt = X
- prpOrt0 :: Oriented q => X q -> Statement
- prpOrt1 :: Oriented q => X q -> Statement
- xosOrt :: forall q (s :: Site). Oriented q => XOrtSite s q -> XOrt q
- xosPoint :: forall (s :: Site) q. XOrtSite s q -> X (Point q)
- xoOrt :: XOrtOrientation q -> XOrt q
- xOrtOrnt :: X p -> XOrt (Orientation p)
Oriented
prpOrt0 :: Oriented q => X q -> Statement Source #
validity of the functions orientation, start and end.
prpOrt1 :: Oriented q => X q -> Statement Source #
validity of the relation between orientation, start and end according to
OAlg.Structure.Oriented.Definition.
X
xosOrt :: forall q (s :: Site). Oriented q => XOrtSite s q -> XOrt q Source #
the underlying random variable for Oriented structures.
xosPoint :: forall (s :: Site) q. XOrtSite s q -> X (Point q) Source #
the underlying random variable of .Point g
xoOrt :: XOrtOrientation q -> XOrt q Source #
the underlying random variable for Oriented structures.
Orientation
xOrtOrnt :: X p -> XOrt (Orientation p) Source #
the induced random variable of Oriented structures for .Orientation p