oalg-base-3.0.0.0: Algebraic structures on oriented entities and limits as a tool kit to solve algebraic problems.
Copyright(c) Erich Gut
LicenseBSD3
Maintainerzerich.gut@gmail.com
Safe HaskellNone
LanguageHaskell2010

OAlg.Structure.PartiallyOrdered.Definition

Description

partial orderings..

Synopsis

Partial Ordering

class Eq a => PartiallyOrdered a where Source #

partially ordered types.

Properties Let a be an instance of PartiallyOrdered, then holds:

  1. For all x in a holds: x <<= x.
  2. For all x, y in a holds: If x <<= y and y <<= x then x == y.
  3. For all x, y, z in a holds: If x <<= y and y <<= z then x <<= z.

Methods

(<<=) :: a -> a -> Bool infix 4 Source #

Instances

Instances details
PartiallyOrdered Bool Source # 
Instance details

Defined in OAlg.Structure.PartiallyOrdered.Definition

Methods

(<<=) :: Bool -> Bool -> Bool Source #

Ord x => PartiallyOrdered (Set x) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Set

Methods

(<<=) :: Set x -> Set x -> Bool Source #

PartiallyOrdered x => PartiallyOrdered (Op x) Source # 
Instance details

Defined in OAlg.Structure.PartiallyOrdered.Definition

Methods

(<<=) :: Op x -> Op x -> Bool Source #

Eq x => PartiallyOrdered [x] Source # 
Instance details

Defined in OAlg.Structure.PartiallyOrdered.Definition

Methods

(<<=) :: [x] -> [x] -> Bool Source #

(Ord a, Ord b) => PartiallyOrdered (Graph a (Set b)) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Graph

Methods

(<<=) :: Graph a (Set b) -> Graph a (Set b) -> Bool Source #

class PartiallyOrdered a => Empty a where Source #

the minimal element of a patrially ordered type..

Property Let a be an instance of Empty, then for all x in a holds: empty <<= x.

Minimal complete definition

empty

Methods

empty :: a Source #

isEmpty :: a -> Bool Source #

Instances

Instances details
Empty Bool Source # 
Instance details

Defined in OAlg.Structure.PartiallyOrdered.Definition

Ord x => Empty (Set x) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Set

Methods

empty :: Set x Source #

isEmpty :: Set x -> Bool Source #

Eq x => Empty [x] Source # 
Instance details

Defined in OAlg.Structure.PartiallyOrdered.Definition

Methods

empty :: [x] Source #

isEmpty :: [x] -> Bool Source #

(Ord a, Ord b) => Empty (Graph a (Set b)) Source # 
Instance details

Defined in OAlg.Entity.Sequence.Graph

Methods

empty :: Graph a (Set b) Source #

isEmpty :: Graph a (Set b) -> Bool Source #

class PartiallyOrdered a => Full a where Source #

the maximal element of a partially ordered type.

Property Let a be an instance of Full, then for all x in a holds: x <<= full.

Minimal complete definition

full

Methods

full :: a Source #

isFull :: a -> Bool Source #

Instances

Instances details
Full Bool Source # 
Instance details

Defined in OAlg.Structure.PartiallyOrdered.Definition