| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Hom.Vectorial
Contents
Synopsis
- class (HomAdditive h, Transformable (ObjectClass h) (Vec k)) => HomVectorial k (h :: Type -> Type -> Type)
- class (DualisableAdditive s o, Transformable s (Vec k)) => DualisableVectorial k s (o :: Type -> Type)
- prpHomVectorial :: HomVectorial k h => h x y -> k -> x -> Statement
- prpDualisableVectorial :: forall k s (o :: Type -> Type) q x. DualisableVectorial k s o => q o -> Struct s x -> k -> x -> Statement
- prpHomDisjOpVecZ :: Statement
Vectorial
class (HomAdditive h, Transformable (ObjectClass h) (Vec k)) => HomVectorial k (h :: Type -> Type -> Type) Source #
type family of homomorphisms between Vectorial structures having the same associated 'Scalar.
Property Let h be a type instance of the class , then
for all HomVectorial ka, b, v in h a b and x in k holds:
.amap h (x ! v) == x ! amap h v
Instances
| HomVectorial k h => HomVectorial k (Path h) Source # | |
Defined in OAlg.Hom.Vectorial | |
| (Semiring r, Commutative r) => HomVectorial r (HomSymbol r) Source # | |
Defined in OAlg.Entity.Matrix.Vector | |
| (HomVectorial k h, DualisableVectorial k s o) => HomVectorial k (HomDisj s o h) Source # | |
Defined in OAlg.Hom.Vectorial | |
class (DualisableAdditive s o, Transformable s (Vec k)) => DualisableVectorial k s (o :: Type -> Type) Source #
Proposition
prpHomVectorial :: HomVectorial k h => h x y -> k -> x -> Statement Source #
validity according to HomVectorial.
prpDualisableVectorial :: forall k s (o :: Type -> Type) q x. DualisableVectorial k s o => q o -> Struct s x -> k -> x -> Statement Source #
validity according to DualisableVectorial.
prpHomDisjOpVecZ :: Statement Source #
validity of HomDisjEmpty __(Vec Z) Op@ according to HomVectorial.