| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Cone.Conic.Core
Description
basic definition for objects with a naturally underlying cone.
Synopsis
- class Conic (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) where
- cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. c s p d t n m x -> Cone s p d t n m x
- newtype ConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x = ConeG (c s p d t n m x)
- class (Conic c, HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammatic h d t n m, NaturalTransformable h (->) (SDualBi (ConeG c s p d t n m)) (SDualBi (ConeG Cone s p d t n m)), p ~ Dual (Dual p)) => NaturalConic (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N')
- crohS :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. Conic c => SDualBi (ConeG c s p d t n m) x -> SDualBi (ConeG Cone s p d t n m) x
Conic
class Conic (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) where Source #
object c having an underlying Cone.
Methods
cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. c s p d t n m x -> Cone s p d t n m x Source #
Instances
| Conic ConeLiftable Source # | |
Defined in OAlg.Entity.Slice.Free Methods cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. ConeLiftable s p d t n m x -> Cone s p d t n m x Source # | |
| Conic Cone Source # | |
Defined in OAlg.Limes.Cone.Conic.Core Methods cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. Cone s p d t n m x -> Cone s p d t n m x Source # | |
| Conic ConeZeroHead Source # | |
Defined in OAlg.Limes.Cone.ZeroHead.Core Methods cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. ConeZeroHead s p d t n m x -> Cone s p d t n m x Source # | |
| Conic c => Conic (ConicFreeTip c) Source # | |
Defined in OAlg.Entity.Slice.Free Methods cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. ConicFreeTip c s p d t n m x -> Cone s p d t n m x Source # | |
| Conic (LiftableCone i) Source # | |
Defined in OAlg.Entity.Slice.Liftable Methods cone :: forall s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. LiftableCone i s p d t n m x -> Cone s p d t n m x Source # | |
newtype ConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x Source #
wrapper for Conic-objects.
Constructors
| ConeG (c s p d t n m x) |
Instances
Natural
class (Conic c, HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammatic h d t n m, NaturalTransformable h (->) (SDualBi (ConeG c s p d t n m)) (SDualBi (ConeG Cone s p d t n m)), p ~ Dual (Dual p)) => NaturalConic (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') Source #
natural transformation for Conic objects from to
SDualBi (ConeG c s p d t n m).SDualBi (Cone s p d t n m)
Instances
| (HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalConic h Cone Dst p d t n m Source # | |
Defined in OAlg.Limes.Cone.Conic.Duality | |
| (HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalConic h Cone Mlt p d t n m Source # | |
Defined in OAlg.Limes.Cone.Conic.Duality | |
| (HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => NaturalConic h ConeZeroHead Mlt p d t n m Source # | |
Defined in OAlg.Limes.Cone.ZeroHead.Duality | |
| (CategoryDisjunctive h, HomSlicedDistributive i h, FunctorialOriented h, p ~ Dual (Dual p), t ~ Dual (Dual t), s ~ Dst) => NaturalConic (Inv2 h) (LiftableCone i) s p Diagram t n m Source # | |
Defined in OAlg.Entity.Slice.Liftable | |
crohS :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. Conic c => SDualBi (ConeG c s p d t n m) x -> SDualBi (ConeG Cone s p d t n m) x Source #