| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Cone.Duality
Description
definition of duality for Cones over Diagrammatic objects.
Synopsis
- cnMapS :: forall s h (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') (p :: Perspective) x y. (HomD s h, NaturalDiagrammatic h d t n m, NaturalDiagrammatic h d (Dual t) n m, p ~ Dual (Dual p)) => h x y -> SDualBi (Cone s p d t n m) x -> SDualBi (Cone s p d t n m) y
- cnMapCov :: forall s (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomD s h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone s p d t n m x -> Cone s p d t n m y
- cnMapMltCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomMultiplicativeDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone Mlt p d t n m x -> Cone Mlt p d t n m y
- cnMapDstCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone Dst p d t n m x -> Cone Dst p d t n m y
- cnMap :: forall s h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (Hom s h, t ~ Dual (Dual t)) => h x y -> Cone s p Diagram t n m x -> Cone s p Diagram t n m y
- cnMapMlt :: forall h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (HomMultiplicative h, t ~ Dual (Dual t)) => h x y -> Cone Mlt p Diagram t n m x -> Cone Mlt p Diagram t n m y
- cnMapDst :: forall h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (HomDistributive h, t ~ Dual (Dual t)) => h x y -> Cone Dst p Diagram t n m x -> Cone Dst p Diagram t n m y
- cnMapCnt :: forall s (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomD s h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone s p d t n m x -> Dual1 (Cone s p d t n m) y
- cnMapMltCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomMultiplicativeDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone Mlt p d t n m x -> Dual1 (Cone Mlt p d t n m) y
- cnMapDstCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone Dst p d t n m x -> Dual1 (Cone Dst p d t n m) y
Map
cnMapS :: forall s h (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') (p :: Perspective) x y. (HomD s h, NaturalDiagrammatic h d t n m, NaturalDiagrammatic h d (Dual t) n m, p ~ Dual (Dual p)) => h x y -> SDualBi (Cone s p d t n m) x -> SDualBi (Cone s p d t n m) y Source #
mapping of Cone.
Covariant
cnMapCov :: forall s (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomD s h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone s p d t n m x -> Cone s p d t n m y Source #
covariant mapping of Cone.
cnMapMltCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomMultiplicativeDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone Mlt p d t n m x -> Cone Mlt p d t n m y Source #
mapping of a cone under a Multiplicative covariant homomorphism.
cnMapDstCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> Cone Dst p d t n m x -> Cone Dst p d t n m y Source #
mapping of a cone under a Distributive covariant homomorphism.
cnMap :: forall s h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (Hom s h, t ~ Dual (Dual t)) => h x y -> Cone s p Diagram t n m x -> Cone s p Diagram t n m y Source #
mapping of a cone under a s homomorphism.
cnMapMlt :: forall h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (HomMultiplicative h, t ~ Dual (Dual t)) => h x y -> Cone Mlt p Diagram t n m x -> Cone Mlt p Diagram t n m y Source #
mapping of a cone under a Multiplicative homomorphism.
cnMapDst :: forall h (t :: DiagramType) x y (p :: Perspective) (n :: N') (m :: N'). (HomDistributive h, t ~ Dual (Dual t)) => h x y -> Cone Dst p Diagram t n m x -> Cone Dst p Diagram t n m y Source #
mapping of a cone under a Distributive homomorphism.
Contravariant
cnMapCnt :: forall s (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomD s h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone s p d t n m x -> Dual1 (Cone s p d t n m) y Source #
mapping of a cone under a contravariant homomorphism.
cnMapMltCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomMultiplicativeDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone Mlt p d t n m x -> Dual1 (Cone Mlt p d t n m) y Source #
mapping of a cone under a Multiplicative contravariant homomorphism.
cnMapDstCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> Cone Dst p d t n m x -> Dual1 (Cone Dst p d t n m) y Source #
mapping of a cone under a Distributive contravariant homomorphism.
Orphan instances
| (Eq x, EqPoint x) => EqDual1 (Cone s p Diagram t n m :: Type -> Type) (x :: Type) Source # | |
| (Show x, ShowPoint x) => ShowDual1 (Cone s p Diagram t n m :: Type -> Type) (x :: Type) Source # | |
| (HomDistributiveDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (Cone Dst p d t n m)) h (->) Source # | |
| (HomMultiplicativeDisjunctive h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => ApplicativeG (SDualBi (Cone Mlt p d t n m)) h (->) Source # | |
| (HomDistributiveDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (Cone Dst p d t n m)) h (->) Source # | |
| (HomMultiplicativeDisjunctive h, FunctorialOriented h, NaturalDiagrammaticBi h d t n m, p ~ Dual (Dual p)) => FunctorialG (SDualBi (Cone Mlt p d t n m)) h (->) Source # | |