| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Cone.ZeroHead
Contents
Description
cones having a zero for its first arrow.
Synopsis
- data ConeZeroHead s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where
- ConeZeroHead :: forall x s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m1 :: N'). Distributive x => Cone s p d t n (m1 + 1) x -> ConeZeroHead s p d t n (m1 + 1) x
- cnZeroHead :: forall (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') a. Cone Dst p Diagram t n m a -> ConeZeroHead Mlt p Diagram t n (m + 1) a
- cnKernel :: forall (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') a. (p ~ 'Projective, t ~ 'Parallel 'LeftToRight) => ConeZeroHead Mlt p Diagram t n (m + 1) a -> Cone Dst p Diagram t n m a
- cnCokernel :: forall (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') a. (p ~ 'Injective, t ~ 'Parallel 'RightToLeft, n ~ N2) => ConeZeroHead Mlt p Diagram t n (m + 1) a -> Cone Dst p Diagram t n m a
- cnDiffHead :: forall a (p :: Perspective) (d :: Direction) (n :: N') (m :: N'). (Distributive a, Abelian a) => Cone Mlt p Diagram ('Parallel d) n (m + 1) a -> ConeZeroHead Mlt p Diagram ('Parallel d) n (m + 1) a
- module OAlg.Limes.Cone.ZeroHead.Duality
Documentation
data ConeZeroHead s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where Source #
predicate for cones where the first arrow of its underlying diagram is equal to zero.
Constructors
| ConeZeroHead :: forall x s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m1 :: N'). Distributive x => Cone s p d t n (m1 + 1) x -> ConeZeroHead s p d t n (m1 + 1) x |
Instances
cnZeroHead :: forall (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') a. Cone Dst p Diagram t n m a -> ConeZeroHead Mlt p Diagram t n (m + 1) a Source #
embedding of a cone in a distributive structure to its multiplicative cone.
cnKernel :: forall (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') a. (p ~ 'Projective, t ~ 'Parallel 'LeftToRight) => ConeZeroHead Mlt p Diagram t n (m + 1) a -> Cone Dst p Diagram t n m a Source #
the kernel cone of a zero headed parallel cone, i.e. the inverse of cnZeroHead.
cnCokernel :: forall (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') a. (p ~ 'Injective, t ~ 'Parallel 'RightToLeft, n ~ N2) => ConeZeroHead Mlt p Diagram t n (m + 1) a -> Cone Dst p Diagram t n m a Source #
the cokernel cone of a zero headed parallel cone, i.e. the inverse of cnZeroHead.
cnDiffHead :: forall a (p :: Perspective) (d :: Direction) (n :: N') (m :: N'). (Distributive a, Abelian a) => Cone Mlt p Diagram ('Parallel d) n (m + 1) a -> ConeZeroHead Mlt p Diagram ('Parallel d) n (m + 1) a Source #
subtracts to every arrow of the underlying parallel diagram the first arrow and adapts the shell accordingly.