| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Cone.ZeroHead.Duality
Contents
Description
duality for ConeZeroHead.
Synopsis
- czMapS :: forall h (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') (p :: Perspective) x y s. (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m, NaturalDiagrammatic h d (Dual t) n m, p ~ Dual (Dual p)) => h x y -> SDualBi (ConeZeroHead s p d t n m) x -> SDualBi (ConeZeroHead s p d t n m) y
- czMapCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y s (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> ConeZeroHead s p d t n m x -> ConeZeroHead s p d t n m y
- czMapCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y s (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> ConeZeroHead s p d t n m x -> Dual1 (ConeZeroHead s p d t n m) y
Mapp
czMapS :: forall h (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') (p :: Perspective) x y s. (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m, NaturalDiagrammatic h d (Dual t) n m, p ~ Dual (Dual p)) => h x y -> SDualBi (ConeZeroHead s p d t n m) x -> SDualBi (ConeZeroHead s p d t n m) y Source #
mapping of ConeZeroHead
czMapCov :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y s (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Covariant h x y -> ConeZeroHead s p d t n m x -> ConeZeroHead s p d t n m y Source #
covariant mapping of ConeZeroHead
czMapCnt :: forall (h :: Type -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y s (p :: Perspective). (HomDistributiveDisjunctive h, NaturalDiagrammatic h d t n m) => Variant2 'Contravariant h x y -> ConeZeroHead s p d t n m x -> Dual1 (ConeZeroHead s p d t n m) y Source #
contravariant mapping of ConeZeroHead