| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Definition.Proposition
Contents
Description
proposition of a Limes over a Diagrammatic object yielding a Conic object.
Synopsis
- prpLimes :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x. (Conic c, Diagrammatic d, Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => XEligibleConeG c s p d t n m x -> XEligibleConeFactorG c s p d t n m x -> LimesG c s p d t n m x -> Statement
- prpLimesFactorExist :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x. (Conic c, Diagrammatic d, Show (c s p d t n m x), Entity (d t n m x), Entity x) => XEligibleConeG c s p d t n m x -> LimesG c s p d t n m x -> Statement
- prpLimesFactorUnique :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x s (p :: Perspective). (Conic c, Diagrammatic d, Entity (d t n m x), Entity x) => XEligibleConeFactorG c s p d t n m x -> LimesG c s p d t n m x -> Statement
- data XEligibleConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x = XEligibleConeG (LimesG c s p d t n m x -> X (Cone s p d t n m x))
- xec :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. XEligibleConeG c s p d t n m x -> LimesG c s p d t n m x -> X (Cone s p d t n m x)
- xecMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (XEligibleConeG c s p d t n m) x -> SDualBi (XEligibleConeG c s p d t n m) y
- xecMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> XEligibleConeG c s p d t n m x -> XEligibleConeG c s p d t n m y
- xecMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> XEligibleConeG c s p d t n m x -> Dual1 (XEligibleConeG c s p d t n m) y
- xEligibleConeGOrnt :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) x s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N'). (Conic c, Diagrammatic d) => X x -> XEligibleConeG c s p d t n m (Orientation x)
- coXEligibleConeG :: forall x s (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N'). (Multiplicative x, NaturalConicBi (Inv2 (HomDisjEmpty s Op)) c s p d t n m, s ~ Mlt) => XEligibleConeG c s p d t n m x -> XEligibleConeG c s (Dual p) d (Dual t) n m (Op x)
- xecDiscrete :: forall x (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (n :: N') (m :: N'). (Multiplicative x, Conic c, Diagrammatic d) => XOrtOrientation x -> XEligibleConeG c s p d 'Discrete n m x
- class XStandardEligibleConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where
- xStandardEligibleConeG :: XEligibleConeG c s p d t n m x
- class XStandardEligibleConeG Cone s p Diagram t n m x => XStandardEligibleCone s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x
- data XEligibleConeFactorG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x = XEligibleConeFactorG (LimesG c s p d t n m x -> X (Cone s p d t n m x, x))
- xecf :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. XEligibleConeFactorG c s p d t n m x -> LimesG c s p d t n m x -> X (Cone s p d t n m x, x)
- xecfMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (XEligibleConeFactorG c s p d t n m) x -> SDualBi (XEligibleConeFactorG c s p d t n m) y
- xecfMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> XEligibleConeFactorG c s p d t n m x -> XEligibleConeFactorG c s p d t n m y
- xecfMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> XEligibleConeFactorG c s p d t n m x -> XEligibleConeFactorG c s (Dual p) d (Dual t) n m y
- xEligibleConeFactorGOrnt :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) x s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N'). (Conic c, Diagrammatic d) => X x -> XEligibleConeFactorG c s p d t n m (Orientation x)
- coXEligibleConeFactorG :: forall x s (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N'). (Multiplicative x, NaturalConicBi (Inv2 (HomDisjEmpty s Op)) c s p d t n m, s ~ Mlt) => XEligibleConeFactorG c s p d t n m x -> XEligibleConeFactorG c s (Dual p) d (Dual t) n m (Op x)
- xecfOrtSite :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (r :: Site) x s (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N'). Conic c => XOrtSite r x -> XEligibleConeFactorG c s (ToPerspective r) d t n m x
- xecfEligibleCone :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. XEligibleConeFactorG c s p d t n m x -> XEligibleConeG c s p d t n m x
- class XStandardEligibleConeFactorG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where
- xStandardEligibleConeFactorG :: XEligibleConeFactorG c s p d t n m x
- class XStandardEligibleConeFactorG Cone s p Diagram t n m x => XStandardEligibleConeFactor s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x
Proposition
prpLimes :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x. (Conic c, Diagrammatic d, Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => XEligibleConeG c s p d t n m x -> XEligibleConeFactorG c s p d t n m x -> LimesG c s p d t n m x -> Statement Source #
validity according to LimesG.
prpLimesFactorExist :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x. (Conic c, Diagrammatic d, Show (c s p d t n m x), Entity (d t n m x), Entity x) => XEligibleConeG c s p d t n m x -> LimesG c s p d t n m x -> Statement Source #
prpLimesFactorUnique :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x s (p :: Perspective). (Conic c, Diagrammatic d, Entity (d t n m x), Entity x) => XEligibleConeFactorG c s p d t n m x -> LimesG c s p d t n m x -> Statement Source #
X
data XEligibleConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x Source #
random variable for eligible cones for a given limes.
Constructors
| XEligibleConeG (LimesG c s p d t n m x -> X (Cone s p d t n m x)) |
Instances
| type Dual1 (XEligibleConeG c s p d t n m :: Type -> Type) Source # | |
Defined in OAlg.Limes.Definition.Proposition type Dual1 (XEligibleConeG c s p d t n m :: Type -> Type) = XEligibleConeG c s (Dual p) d (Dual t) n m | |
xec :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. XEligibleConeG c s p d t n m x -> LimesG c s p d t n m x -> X (Cone s p d t n m x) Source #
random variable of eligible cones.
xecMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (XEligibleConeG c s p d t n m) x -> SDualBi (XEligibleConeG c s p d t n m) y Source #
mapping of a XEligibleConeG.
xecMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> XEligibleConeG c s p d t n m x -> XEligibleConeG c s p d t n m y Source #
mapping according to a covariant isomorphism.
xecMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> XEligibleConeG c s p d t n m x -> Dual1 (XEligibleConeG c s p d t n m) y Source #
mapping according to a contravariant isomorphism.
xEligibleConeGOrnt :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) x s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N'). (Conic c, Diagrammatic d) => X x -> XEligibleConeG c s p d t n m (Orientation x) Source #
random variable of eligible Cones over Orientation.
coXEligibleConeG :: forall x s (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N'). (Multiplicative x, NaturalConicBi (Inv2 (HomDisjEmpty s Op)) c s p d t n m, s ~ Mlt) => XEligibleConeG c s p d t n m x -> XEligibleConeG c s (Dual p) d (Dual t) n m (Op x) Source #
random variable for eligible cones over Op.
xecDiscrete :: forall x (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (n :: N') (m :: N'). (Multiplicative x, Conic c, Diagrammatic d) => XOrtOrientation x -> XEligibleConeG c s p d 'Discrete n m x Source #
random variable for eligible cones over Discrete diagrammtic objects
class XStandardEligibleConeG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where Source #
standard random variable for eligible cones.
Methods
xStandardEligibleConeG :: XEligibleConeG c s p d t n m x Source #
Instances
| (Conic c, Diagrammatic d) => XStandardEligibleConeG c Mlt p d 'Discrete n m (Matrix Z) Source # | |
Defined in OAlg.Entity.Matrix.Definition Methods xStandardEligibleConeG :: XEligibleConeG c Mlt p d 'Discrete n m (Matrix Z) Source # | |
| (Conic c, Diagrammatic d, XStandard x) => XStandardEligibleConeG c s p d t n m (Orientation x) Source # | |
Defined in OAlg.Limes.Definition.Proposition Methods xStandardEligibleConeG :: XEligibleConeG c s p d t n m (Orientation x) Source # | |
class XStandardEligibleConeG Cone s p Diagram t n m x => XStandardEligibleCone s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x Source #
helper class to avoid undecidable instances.
data XEligibleConeFactorG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x Source #
random variable for eligible cones together with a eligible factor for a given limes.
Constructors
| XEligibleConeFactorG (LimesG c s p d t n m x -> X (Cone s p d t n m x, x)) |
Instances
| type Dual1 (XEligibleConeFactorG c s p d t n m :: Type -> Type) Source # | |
Defined in OAlg.Limes.Definition.Proposition type Dual1 (XEligibleConeFactorG c s p d t n m :: Type -> Type) = XEligibleConeFactorG c s (Dual p) d (Dual t) n m | |
xecf :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. XEligibleConeFactorG c s p d t n m x -> LimesG c s p d t n m x -> X (Cone s p d t n m x, x) Source #
random variable of eligible cone factors.
xecfMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (XEligibleConeFactorG c s p d t n m) x -> SDualBi (XEligibleConeFactorG c s p d t n m) y Source #
mapping of XEligibleConeFactorG
xecfMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> XEligibleConeFactorG c s p d t n m x -> XEligibleConeFactorG c s p d t n m y Source #
covariant mapping of XEligibleConeFactorG
xecfMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> XEligibleConeFactorG c s p d t n m x -> XEligibleConeFactorG c s (Dual p) d (Dual t) n m y Source #
contravariant mapping of XEligibleConeFactorG
xEligibleConeFactorGOrnt :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (d :: DiagramType -> N' -> N' -> Type -> Type) x s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N'). (Conic c, Diagrammatic d) => X x -> XEligibleConeFactorG c s p d t n m (Orientation x) Source #
random variable of eligible factors over Orientation.
coXEligibleConeFactorG :: forall x s (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N'). (Multiplicative x, NaturalConicBi (Inv2 (HomDisjEmpty s Op)) c s p d t n m, s ~ Mlt) => XEligibleConeFactorG c s p d t n m x -> XEligibleConeFactorG c s (Dual p) d (Dual t) n m (Op x) Source #
the co-object of XEligibleConeFactorG accordint to Op.
xecfOrtSite :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) (r :: Site) x s (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N'). Conic c => XOrtSite r x -> XEligibleConeFactorG c s (ToPerspective r) d t n m x Source #
the random variable XEligibleConeFactorG given be XOrtSite.
xecfEligibleCone :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x. XEligibleConeFactorG c s p d t n m x -> XEligibleConeG c s p d t n m x Source #
the induced random variable for eligible cones.
class XStandardEligibleConeFactorG (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x where Source #
standard random variable for eligible cone factors.
Methods
xStandardEligibleConeFactorG :: XEligibleConeFactorG c s p d t n m x Source #
Instances
| Conic c => XStandardEligibleConeFactorG c Mlt 'Injective d 'Discrete n m (Matrix Z) Source # | |
Defined in OAlg.Entity.Matrix.Definition Methods xStandardEligibleConeFactorG :: XEligibleConeFactorG c Mlt 'Injective d 'Discrete n m (Matrix Z) Source # | |
| Conic c => XStandardEligibleConeFactorG c Mlt 'Projective d 'Discrete n m (Matrix Z) Source # | |
Defined in OAlg.Entity.Matrix.Definition Methods xStandardEligibleConeFactorG :: XEligibleConeFactorG c Mlt 'Projective d 'Discrete n m (Matrix Z) Source # | |
| (Conic c, Diagrammatic d, XStandard x) => XStandardEligibleConeFactorG c s p d t n m (Orientation x) Source # | |
Defined in OAlg.Limes.Definition.Proposition Methods xStandardEligibleConeFactorG :: XEligibleConeFactorG c s p d t n m (Orientation x) Source # | |
class XStandardEligibleConeFactorG Cone s p Diagram t n m x => XStandardEligibleConeFactor s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x Source #
helper class to avoid undecidable instances.
Orphan instances
| (Conic c, Diagrammatic d, XStandardEligibleConeG c s p d t n m x, XStandardEligibleConeFactorG c s p d t n m x, Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => Validable (LimesG c s p d t n m x) Source # | |