| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Exact.ZeroPoint
Contents
Description
zero points within a Distributive structure.
Synopsis
- newtype ZeroPoint x = ZeroPoint (Point x)
- isZeroPoint :: Distributive x => q x -> Point x -> Bool
- zrPointTerminal :: Distributive x => ZeroPoint x -> TerminalPoint x
- zrPointTerminals :: Distributive x => ZeroPoint x -> Terminals x
- zrPointInitial :: Distributive x => ZeroPoint x -> InitialPoint x
- zrPointInitials :: Distributive x => ZeroPoint x -> Initials x
Zero Point
predicate for a zero point within a Distributive structure x.
Property Let be in ZeroPoint z within a
ZeroPoint xDistributive structure x, then holds:
isZeroPoint :: Distributive x => q x -> Point x -> Bool Source #
testing of being a zero point accroding to the given proxy type.
Limes
zrPointTerminal :: Distributive x => ZeroPoint x -> TerminalPoint x Source #
a zero point as terminal point.
zrPointTerminals :: Distributive x => ZeroPoint x -> Terminals x Source #
the induced terminals.
zrPointInitial :: Distributive x => ZeroPoint x -> InitialPoint x Source #
a zero point as initial point.
zrPointInitials :: Distributive x => ZeroPoint x -> Initials x Source #
the induced initials.