| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Limits.Duality
Contents
Description
duality for LimitsG.
Synopsis
- lmsMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (LimitsG c s p d t n m) x -> SDualBi (LimitsG c s p d t n m) y
- lmsMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> LimitsG c s p d t n m x -> LimitsG c s p d t n m y
- lmsMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> LimitsG c s p d t n m x -> Dual1 (LimitsG c s p d t n m) y
Mapp
lmsMapS :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Inv2 h x y -> SDualBi (LimitsG c s p d t n m) x -> SDualBi (LimitsG c s p d t n m) y Source #
mapping for LimitsG.
lmsMapCov :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Covariant (Inv2 h) x y -> LimitsG c s p d t n m x -> LimitsG c s p d t n m y Source #
covariant mapping for LimitsG.
lmsMapCnt :: forall (h :: Type -> Type -> Type) (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) s (p :: Perspective) (d :: DiagramType -> N' -> N' -> Type -> Type) (t :: DiagramType) (n :: N') (m :: N') x y. NaturalConicBi (Inv2 h) c s p d t n m => Variant2 'Contravariant (Inv2 h) x y -> LimitsG c s p d t n m x -> Dual1 (LimitsG c s p d t n m) y Source #
contravariant mapping for LimitsG.
Orphan instances
| NaturalConicBi (Inv2 h) c s p d t n m => ApplicativeG (SDualBi (LimitsG c s p d t n m)) (Inv2 h) (->) Source # | |
| NaturalConicBi (Inv2 h) c s p d t n m => FunctorialG (SDualBi (LimitsG c s p d t n m)) (Inv2 h) (->) Source # | |