| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Limes.Limits.Proposition
Contents
Description
duality for LimitsG.
Synopsis
- prpLimitsG :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) d s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x. (Conic c, Diagrammatic d, Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => XEligibleConeG c s p d t n m x -> XEligibleConeFactorG c s p d t n m x -> X (d t n m x) -> LimitsG c s p d t n m x -> Statement
Proposition
prpLimitsG :: forall (c :: Type -> Perspective -> (DiagramType -> N' -> N' -> Type -> Type) -> DiagramType -> N' -> N' -> Type -> Type) d s (p :: Perspective) (t :: DiagramType) (n :: N') (m :: N') x. (Conic c, Diagrammatic d, Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => XEligibleConeG c s p d t n m x -> XEligibleConeFactorG c s p d t n m x -> X (d t n m x) -> LimitsG c s p d t n m x -> Statement Source #
validity according to LimitsG.
Orphan instances
| (Conic c, Diagrammatic d, XStandardEligibleConeG c s p d t n m x, XStandardEligibleConeFactorG c s p d t n m x, XStandard (d t n m x), Show (c s p d t n m x), Validable (c s p d t n m x), Entity (d t n m x), Entity x) => Validable (LimitsG c s p d t n m x) Source # | |