| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Structure.Oriented.Definition
Description
General definition of Oriented structures.
Synopsis
- class (Entity q, EntityPoint q) => Oriented q where
- orientation :: q -> Orientation (Point q)
- start :: q -> Point q
- end :: q -> Point q
- isEndo :: Oriented q => q -> Bool
- isEndoAt :: Oriented a => Point a -> a -> Bool
- data Ort
- tauOrt :: Transformable s Ort => Struct s x -> Struct Ort x
- class Transformable s Ort => TransformableOrt s
- module OAlg.Structure.Oriented.Point
- module OAlg.Structure.Oriented.Orientation
- class (Transposable q, Oriented q) => TransposableOriented q
- type EqualExtOrt = Sub EqEOrt (->)
- data EqEOrt
- data OrtX
Oriented
class (Entity q, EntityPoint q) => Oriented q where Source #
types with a Oriented structure. The values of an Oriented structure will
be called arrows and the values of the associated Point type points. To each
arrow there is a start and a end point assigned.
Property Let q be a type instance of the class Oriented, then holds:
- For all
ainqholds:.orientationa==starta:>enda
Note
- If the types
qandare interpreted as setsPointqAandPandstart,endas functions fromAtoPthen this structure forms a quiver with arrows inAand points inP. Morphisms can be interpreted asOrientedstructures viaSomeMorphism. The bad thing about this is that we lose the check for composability of twoMorphisms given by the type checker, but we gain all the functionality ofOrientedstructures, i.e we can define homomorphisms, limits etc onMorphisms.
Minimal complete definition
orientation | start, end
Methods
orientation :: q -> Orientation (Point q) Source #
the orientation of an arrow.
start :: q -> Point q Source #
the start point of an arrow.
the end point of an arrow.
Instances
type representing the class of Oriented structures.
Instances
class Transformable s Ort => TransformableOrt s Source #
helper class to avoid undecidable instances.
Instances
| TransformableOrt Dst Source # | |
Defined in OAlg.Structure.Distributive.Definition | |
| TransformableOrt DstX Source # | |
Defined in OAlg.Structure.Distributive.Proposition | |
| TransformableOrt FbrOrt Source # | |
Defined in OAlg.Structure.FibredOriented | |
| TransformableOrt FbrOrtX Source # | |
Defined in OAlg.Structure.FibredOriented | |
| TransformableOrt Mlt Source # | |
Defined in OAlg.Structure.Multiplicative.Definition | |
| TransformableOrt MltX Source # | |
Defined in OAlg.Structure.Multiplicative.Proposition | |
| TransformableOrt Ort Source # | |
Defined in OAlg.Structure.Oriented.Definition | |
| TransformableOrt OrtX Source # | |
Defined in OAlg.Structure.Oriented.Definition | |
| TransformableOrt OrtSiteX Source # | |
Defined in OAlg.Structure.Oriented.X | |
| TransformableOrt (Alg k) Source # | |
Defined in OAlg.Structure.Algebraic.Definition | |
| TransformableOrt s => TransformableOrt (s, SldFr) Source # | |
Defined in OAlg.Entity.Slice.Free | |
| Transformable s Ort => TransformableOrt (s, Sld i) Source # | |
Defined in OAlg.Entity.Slice.Sliced | |
Duality
Transposable
class (Transposable q, Oriented q) => TransposableOriented q Source #
transposable oriented structures.
Property Let q be a TransposableOriented structure, then holds:
For all a in q holds:
.orientation (transpose a) == opposite (orientation a)
Instances
| TransposableOriented N Source # | |
Defined in OAlg.Structure.Oriented.Definition | |
| TransposableOriented Q Source # | |
Defined in OAlg.Structure.Oriented.Definition | |
| TransposableOriented Z Source # | |
Defined in OAlg.Structure.Oriented.Definition | |
| (Distributive x, TransposableDistributive x) => TransposableOriented (Matrix x) Source # | |
Defined in OAlg.Entity.Matrix.Definition | |
| (Galoisian x, TransposableDistributive x) => TransposableOriented (GL2 x) Source # | |
Defined in OAlg.Entity.Matrix.GeneralLinearGroup | |
| TransposableMultiplicative c => TransposableOriented (Inv c) Source # | |
Defined in OAlg.Structure.Multiplicative.Definition | |
| Entity p => TransposableOriented (Orientation p) Source # | |
Defined in OAlg.Structure.Oriented.Definition | |
Extensional Equlity
type EqualExtOrt = Sub EqEOrt (->) Source #
category of extensional equality for Oriented structures.
type representing extensional equality for Oriented structures.
Instances
X
type representing the class of Oriented structures with associated standard random
variables.