| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Structure.Oriented.Path
Contents
Description
Paths
Path
a path in a Oriented structure q starting at a given point.
Definition Let q be a Oriented structure and p = a
path in Path s [a 0..a (n-1)]q, then p is valid if and only if
sisvalidanda iarevalidfor alli = 0..n-1.andstart(a (n-1))==sfor allstart(a i)==end(a (n+1))i = 0..n-2.
furthermore n is called the length of p.
Note Paths admit a canonical embedding in to Product.