| Copyright | (c) Erich Gut |
|---|---|
| License | BSD3 |
| Maintainer | zerich.gut@gmail.com |
| Safe Haskell | None |
| Language | Haskell2010 |
OAlg.Structure.Oriented.X
Contents
Description
random variables for Oriented structures.
Synopsis
- data XOrtSite (s :: Site) q where
- data OrtSiteX
- class XStandardOrtSite (s :: Site) a where
- xStandardOrtSite :: XOrtSite s a
- class XStandardOrtSite 'To a => XStandardOrtSiteTo a
- class XStandardOrtSite 'From a => XStandardOrtSiteFrom a
- coXOrtSite :: forall (s :: Site) q. XOrtSite s q -> Dual (XOrtSite s q)
- coXOrtSiteInv :: forall (s :: Site) q. (Dual (Dual s) :~: s) -> Dual (XOrtSite s q) -> XOrtSite s q
- xosFromOpOp :: forall (s :: Site) q. XOrtSite s (Op (Op q)) -> XOrtSite s q
- xosStart :: XOrtSite 'From q -> Point q -> X q
- xosEnd :: XOrtSite 'To q -> Point q -> X q
- xosPathMaxAt :: forall q (s :: Site). Oriented q => XOrtSite s q -> N -> Point q -> X (Path q)
- xosPathMax :: forall q (s :: Site). Oriented q => XOrtSite s q -> N -> X (Path q)
- data XOrtOrientation q = XOrtOrientation (X (Orientation (Point q))) (Orientation (Point q) -> X q)
- xoOrientation :: XOrtOrientation q -> X (Orientation (Point q))
- xoArrow :: XOrtOrientation q -> Orientation (Point q) -> X q
- xoPoint :: Oriented q => XOrtOrientation q -> X (Point q)
- coXOrtOrientation :: XOrtOrientation q -> Dual (XOrtOrientation q)
- xoTo :: Oriented q => XOrtOrientation q -> XOrtSite 'To q
- xoFrom :: Oriented q => XOrtOrientation q -> XOrtSite 'From q
- xoTtl :: Total q => X q -> XOrtOrientation q
- xoOrnt :: X p -> XOrtOrientation (Orientation p)
- class XStandardOrtOrientation q where
- xStartOrnt :: X p -> XOrtSite 'From (Orientation p)
- xEndOrnt :: X p -> XOrtSite 'To (Orientation p)
Site
data XOrtSite (s :: Site) q where Source #
random variables and X q for
X (Point q)Oriented structure q.
Properties Let q be an instance of the class Oriented, then holds:
- Let
be inXStartxp xStart, then holds: For allXOrtSiteFromqpinandPointqxin the range ofxStart pholds:.startx==p - Let
be inXEndxp xEnd, then holds: For allXOrtSiteToqpinandPointqxin the range ofxEnd pholds:.endx==p
Note The random variables xp should have a bias to non trivial random variables
xp or >>= xStartxp .>>= xEnd
Constructors
| XStart :: forall q. X (Point q) -> (Point q -> X q) -> XOrtSite 'From q | |
| XEnd :: forall q. X (Point q) -> (Point q -> X q) -> XOrtSite 'To q |
type for Oriented structures admitting XStandardOrtSiteTo and XStandardOrtSiteFrom.
Note The main point is that holds!TransformableG Op OrtSiteX OrtSiteX
Instances
| TransformableType OrtSiteX Source # | |
Defined in OAlg.Structure.Oriented.X | |
| TransformableOrt OrtSiteX Source # | |
Defined in OAlg.Structure.Oriented.X | |
| TransformableOp OrtSiteX Source # | |
Defined in OAlg.Structure.Oriented.X | |
| Transformable OrtSiteX Typ Source # | |
| Transformable OrtSiteX Ort Source # | |
| Transformable OrtSiteX Type Source # | |
| TransformableGRefl Op OrtSiteX Source # | |
Defined in OAlg.Structure.Oriented.X | |
| TransformableG Op OrtSiteX OrtSiteX Source # | |
| (Attestable m, n ~ (m + 1)) => TransformableG (SDualBi (Diagram ('Chain 'From) n m)) OrtSiteX EqE Source # | |
| (Attestable m, n ~ (m + 1)) => TransformableG (SDualBi (Diagram ('Chain 'To) n m)) OrtSiteX EqE Source # | |
| type Structure OrtSiteX x Source # | |
Defined in OAlg.Structure.Oriented.X | |
class XStandardOrtSite (s :: Site) a where Source #
standard random variable for XOrtSite.
Methods
xStandardOrtSite :: XOrtSite s a Source #
Instances
class XStandardOrtSite 'To a => XStandardOrtSiteTo a Source #
Instances
| XStandardOrtSiteTo x => XStandardOrtSiteTo (Id x) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| XStandardOrtSiteFrom x => XStandardOrtSiteTo (Op x) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| XStandard p => XStandardOrtSiteTo (Orientation p) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| XStandard x => XStandardOrtSiteTo (U x) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| (Multiplicative x, Sliced i x, XStandardOrtSite 'To x) => XStandardOrtSiteTo (SliceFactor 'To i x) Source # | |
Defined in OAlg.Entity.Slice.Definition | |
class XStandardOrtSite 'From a => XStandardOrtSiteFrom a Source #
Instances
| XStandardOrtSiteFrom x => XStandardOrtSiteFrom (Id x) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| XStandardOrtSiteFrom (Matrix Z) Source # | |
Defined in OAlg.Entity.Matrix.Definition | |
| XStandardOrtSiteTo x => XStandardOrtSiteFrom (Op x) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| XStandard p => XStandardOrtSiteFrom (Orientation p) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| XStandard x => XStandardOrtSiteFrom (U x) Source # | |
Defined in OAlg.Structure.Oriented.X | |
| (Multiplicative x, Sliced i x, XStandardOrtSite 'From x) => XStandardOrtSiteFrom (SliceFactor 'From i x) Source # | |
Defined in OAlg.Entity.Slice.Definition | |
| XStandardOrtSiteFrom (SliceFactor 'To (Proxy :: Type -> Type) OS) Source # | |
Defined in OAlg.Entity.Slice.Definition | |
coXOrtSite :: forall (s :: Site) q. XOrtSite s q -> Dual (XOrtSite s q) Source #
to the dual of a , with inverse XOrtSite s qcoXOrtSiteInv.
coXOrtSiteInv :: forall (s :: Site) q. (Dual (Dual s) :~: s) -> Dual (XOrtSite s q) -> XOrtSite s q Source #
from the dual of a , with inverse Dual (XOrtSite s q)coXOrtSite.
xosFromOpOp :: forall (s :: Site) q. XOrtSite s (Op (Op q)) -> XOrtSite s q Source #
from the bidual.
xosStart :: XOrtSite 'From q -> Point q -> X q Source #
the random variable of arrows in q having all as start the given point.
xosEnd :: XOrtSite 'To q -> Point q -> X q Source #
the random variable of arrows in q having all as end the given point.
xosPathMaxAt :: forall q (s :: Site). Oriented q => XOrtSite s q -> N -> Point q -> X (Path q) Source #
tries to make a path at the given point with maximal length of the given length.
Properties Let xPath = , then holds:xosPathMaxAt xos n x
xosPathMax :: forall q (s :: Site). Oriented q => XOrtSite s q -> N -> X (Path q) Source #
random variable of paths with maximal length of the given length.
Orientation
data XOrtOrientation q Source #
random variable of arrows given by an orientation.
Properties Let be in XOrtOrientation xo xArrow for a
XOrtOrientation qOriented structure q, then holds: For all o in and Orientation qx in the
range of xArrow o holds: .orientation x == o
Note The random variable xo should have a bias to non trivial random variables
xo and as such the range of >>= xArrowxo should be included in one connection component
of q.
Constructors
| XOrtOrientation (X (Orientation (Point q))) (Orientation (Point q) -> X q) |
Instances
| Oriented q => Validable (XOrtOrientation q) Source # | |
Defined in OAlg.Structure.Oriented.X Methods valid :: XOrtOrientation q -> Statement Source # | |
| type Dual (XOrtOrientation q :: Type) Source # | |
Defined in OAlg.Structure.Oriented.X | |
xoOrientation :: XOrtOrientation q -> X (Orientation (Point q)) Source #
the underlying random variable of orientations.
xoArrow :: XOrtOrientation q -> Orientation (Point q) -> X q Source #
the underlying random variable of arrow given by the orientation.
xoPoint :: Oriented q => XOrtOrientation q -> X (Point q) Source #
the underlying random variable of points, i.e. the union of the induced start and end
random variable of xoOrientation.
coXOrtOrientation :: XOrtOrientation q -> Dual (XOrtOrientation q) Source #
to the dual.
xoTtl :: Total q => X q -> XOrtOrientation q Source #
random variable of for a total XOrtOrientation qq.
xoOrnt :: X p -> XOrtOrientation (Orientation p) Source #
the induced random variable of .Orientation q
class XStandardOrtOrientation q where Source #
standard random variable for XOrtOrientation.
Methods
Instances
| XStandardOrtOrientation Z Source # | |
Defined in OAlg.Structure.Oriented.X Methods | |
| XStandardOrtOrientation x => XStandardOrtOrientation (Id x) Source # | |
Defined in OAlg.Structure.Oriented.X Methods | |
| (Distributive x, XStandardOrtOrientation x) => XStandardOrtOrientation (Matrix x) Source # | |
Defined in OAlg.Entity.Matrix.Definition Methods xStandardOrtOrientation :: XOrtOrientation (Matrix x) Source # | |
| XStandardOrtOrientation x => XStandardOrtOrientation (Op x) Source # | |
Defined in OAlg.Structure.Oriented.X Methods | |
| XStandard p => XStandardOrtOrientation (Orientation p) Source # | |
Defined in OAlg.Structure.Oriented.X Methods xStandardOrtOrientation :: XOrtOrientation (Orientation p) Source # | |
| XStandard x => XStandardOrtOrientation (U x) Source # | |
Defined in OAlg.Structure.Oriented.X Methods | |
Orientation
xStartOrnt :: X p -> XOrtSite 'From (Orientation p) Source #
the for XOrtSite From of the given random variable.Orientation p
xEndOrnt :: X p -> XOrtSite 'To (Orientation p) Source #
the of XOrtSite To of the given random variable.Orientation p